@@ -19,18 +19,23 @@
 
 // ROOT
 #include "TClass.h"
+#include "TFunction.h"
 #include "TMethod.h"
+
+#include "TClonesArray.h"
 #include "TCollection.h"
 #include "TDirectory.h"
-#include "TSeqCollection.h"
-#include "TClonesArray.h"
-#include "TObject.h"
-#include "TFunction.h"
 #include "TError.h"
+#include "TObject.h"
+#include "TObjArray.h"
+#include "TSeqCollection.h"
 
 #include "TTree.h"
 #include "TBranch.h"
+#include "TBranchElement.h"
 #include "TLeaf.h"
+#include "TStreamerElement.h"
+#include "TStreamerInfo.h"
 
 // CINT
 #include "Api.h"
@@ -748,6 +753,23 @@ namespace {
       return index;
    }
 
+//- TObjArray behavior ---------------------------------------------------------
+   PyObject* TObjArrayLen( PyObject* self )
+   {
+   // GetSize on a TObjArray returns its capacity, not size in use
+      PyObject* size = CallPyObjMethod( self, "GetLast" );
+      if ( ! size )
+         return 0;
+
+      long lsize = PyLong_AsLong( size );
+      if ( lsize == -1 && PyErr_Occurred() )
+         return 0;
+
+      Py_DECREF( size );
+      return PyInt_FromLong( lsize + 1 );
+   }
+
+
 //- TClonesArray behavior ------------------------------------------------------
    PyObject* TClonesArraySetItem( ObjectProxy* self, PyObject* args )
    {
@@ -1233,9 +1255,23 @@ namespace PyROOT {      // workaround for Intel icc on Linux
 
       if ( branch ) {
       // found a branched object, wrap its address for the object it represents
+
+      // for partial return of a split object
+         if ( branch->InheritsFrom(TBranchElement::Class()) ) {
+            TBranchElement* be = (TBranchElement*)branch;
+            if ( be->GetCurrentClass() != be->GetTargetClass() && 0 <= be->GetID() ) {
+               Long_t offset = ((TStreamerElement*)be->GetInfo()->GetElements()->At(be->GetID()))->GetOffset();
+               return BindRootObjectNoCast( be->GetObject() + offset, be->GetCurrentClass() );
+            }
+         }
+
+      // for return of a full object
          TClass* klass = TClass::GetClass( branch->GetClassName() );
          if ( klass && branch->GetAddress() )
             return BindRootObjectNoCast( *(char**)branch->GetAddress(), klass );
+
+      // indicate failure by returning a typed null-object
+         return BindRootObjectNoCast( NULL, klass );
       }
 
    // if not, try leaf
@@ -1257,7 +1293,11 @@ namespace PyROOT {      // workaround for Intel icc on Linux
          // array types
             std::string typeName = leaf->GetTypeName();
             TConverter* pcnv = CreateConverter( typeName + '*', leaf->GetNdata() );
-            void* address = (void*)leaf->GetValuePointer();
+
+            void* address = 0;
+            if ( leaf->GetBranch() ) address = (void*)leaf->GetBranch()->GetAddress();
+            if ( ! address ) address = (void*)leaf->GetValuePointer();
+
             PyObject* value = pcnv->FromMemory( &address );
             delete pcnv;
 
@@ -1265,7 +1305,11 @@ namespace PyROOT {      // workaround for Intel icc on Linux
          } else {
          // value types
             TConverter* pcnv = CreateConverter( leaf->GetTypeName() );
-            PyObject* value = pcnv->FromMemory( (void*)leaf->GetValuePointer() );
+            PyObject* value = 0;
+            if ( TClass::GetClass( leaf->GetTypeName() ) )
+               value = pcnv->FromMemory( (void*)*(char**)leaf->GetValuePointer() );
+            else
+               value = pcnv->FromMemory( (void*)leaf->GetValuePointer() );
             delete pcnv;
 
             return value;
@@ -2130,6 +2174,10 @@ Bool_t PyROOT::Pythonize( PyObject* pyclass, const std::string& name )
       return kTRUE;
    }
 
+   if ( name == "TObjArray" ) {
+      Utility::AddToClass( pyclass, "__len__", (PyCFunction) TObjArrayLen, METH_NOARGS );
+   }
+
    if ( name == "TClonesArray" ) {
    // restore base TSeqCollection operator[] to prevent random object creation (it's
    // functionality is equivalent to the operator[](int) const of TClonesArray, but
@@ -2273,9 +2321,6 @@ Bool_t PyROOT::Pythonize( PyObject* pyclass, const std::string& name )
    }
 
    if ( name == "TChain" ) {
-   // pretend a using
-      Utility::AddUsingToClass( pyclass, "Process" );
-
    // allow SetBranchAddress to take object directly, w/o needing AddressOf()
       MethodProxy* original = (MethodProxy*)PyObject_GetAttr( pyclass, PyStrings::gSetBranchAddress );
       MethodProxy* method = MethodProxy_New( "SetBranchAddress", new TChainSetBranchAddress( original ) );
@@ -2337,6 +2382,12 @@ Bool_t PyROOT::Pythonize( PyObject* pyclass, const std::string& name )
       return kTRUE;
    }
 
+   if ( name.substr(0,6) == "TArray" ) {    // allow proper iteration
+      // __len__ is already set from GetSize()
+      Utility::AddToClass( pyclass, "_getitem__unchecked", "__getitem__" );
+      Utility::AddToClass( pyclass, "__getitem__", (PyCFunction) CheckedGetItem, METH_O );
+   }
+
 // Make RooFit 'using' member functions available (not supported by dictionary)
    if ( name == "RooDataHist" )
       return Utility::AddUsingToClass( pyclass, "plotOn" );
