@@ -52,7 +52,9 @@
 
 
 //- data _______________________________________________________________________
-R__EXTERN PyObject* gRootModule;
+namespace PyROOT {
+   R__EXTERN PyObject* gRootModule;
+}
 
 namespace {
 
@@ -122,6 +124,8 @@ namespace {
 //- helpers --------------------------------------------------------------------
 namespace {
 
+   using namespace PyROOT;
+
    inline void AddToGlobalScope( const char* label, TObject* obj, TClass* klass )
    {
    // Bind the given object with the given class in the global scope with the
