@@ -650,7 +650,7 @@ void TQObject::Emit(const char *signal_name)
 
    TString signal = CompressName(signal_name);
 
-   register TQConnection *connection = 0;
+   TQConnection *connection = 0;
 
    // execute class signals
    TList *sigList;
@@ -705,7 +705,7 @@ void TQObject::EmitVA(const char *signal_name, Int_t nargs, va_list ap)
 
    TString signal = CompressName(signal_name);
 
-   register TQConnection *connection = 0;
+   TQConnection *connection = 0;
 
    // execute class signals
    TList *sigList;
@@ -746,7 +746,7 @@ void TQObject::Emit(const char *signal_name, Long_t param)
 
    TString signal = CompressName(signal_name);
 
-   register TQConnection *connection = 0;
+   TQConnection *connection = 0;
 
    // execute class signals
    TList *sigList;
@@ -787,7 +787,7 @@ void TQObject::Emit(const char *signal_name, Long64_t param)
 
    TString signal = CompressName(signal_name);
 
-   register TQConnection *connection = 0;
+   TQConnection *connection = 0;
 
    // execute class signals
    TList *sigList;
@@ -828,7 +828,7 @@ void TQObject::Emit(const char *signal_name, Double_t param)
 
    TString signal = CompressName(signal_name);
 
-   register TQConnection *connection = 0;
+   TQConnection *connection = 0;
 
    // execute class signals
    TList *sigList;
@@ -869,7 +869,7 @@ void TQObject::Emit(const char *signal_name, const char *params)
 
    TString signal = CompressName(signal_name);
 
-   register TQConnection *connection = 0;
+   TQConnection *connection = 0;
 
    // execute class signals
    TList *sigList;
@@ -922,8 +922,8 @@ void TQObject::Emit(const char *signal_name, Long_t *paramArr)
 
    TString signal = CompressName(signal_name);
 
-   register TQConnectionList *clist  = 0;
-   register TQConnection *connection = 0;
+   TQConnectionList *clist  = 0;
+   TQConnection *connection = 0;
 
    // execute class signals
    TList *sigList;
