@@ -1068,8 +1068,8 @@ void TString::ToLower()
 {
    // Change string to lower-case.
 
-   register Ssiz_t n = Length();
-   register char *p = GetPointer();
+   Ssiz_t n = Length();
+   char *p = GetPointer();
    while (n--) {
       *p = tolower((unsigned char)*p);
       p++;
@@ -1081,8 +1081,8 @@ void TString::ToUpper()
 {
    // Change string to upper case.
 
-   register Ssiz_t n = Length();
-   register char *p = GetPointer();
+   Ssiz_t n = Length();
+   char *p = GetPointer();
    while (n--) {
       *p = toupper((unsigned char)*p);
       p++;
@@ -1398,10 +1398,10 @@ TString ToLower(const TString &str)
 {
    // Return a lower-case version of str.
 
-   register Ssiz_t n = str.Length();
+   Ssiz_t n = str.Length();
    TString temp((char)0, n);
-   register const char *uc = str.Data();
-   register       char *lc = (char*)temp.Data();
+   const char *uc = str.Data();
+         char *lc = (char*)temp.Data();
    // Guard against tolower() being a macro
    while (n--) { *lc++ = tolower((unsigned char)*uc); uc++; }
    return temp;
@@ -1412,10 +1412,10 @@ TString ToUpper(const TString &str)
 {
    // Return an upper-case version of str.
 
-   register Ssiz_t n = str.Length();
+   Ssiz_t n = str.Length();
    TString temp((char)0, n);
-   register const char* uc = str.Data();
-   register       char* lc = (char*)temp.Data();
+   const char* uc = str.Data();
+         char* lc = (char*)temp.Data();
    // Guard against toupper() being a macro
    while (n--) { *lc++ = toupper((unsigned char)*uc); uc++; }
    return temp;
@@ -1727,7 +1727,7 @@ void TSubString::ToLower()
    // Convert sub-string to lower-case.
 
    if (!IsNull()) {                             // Ignore null substrings
-      register char *p = fStr.GetPointer() + fBegin;
+      char *p = fStr.GetPointer() + fBegin;
       Ssiz_t n = fExtent;
       while (n--) { *p = tolower((unsigned char)*p); p++;}
    }
@@ -1738,7 +1738,7 @@ void TSubString::ToUpper()
 {
    // Convert sub-string to upper-case.
    if (!IsNull()) {                             // Ignore null substrings
-      register char *p = fStr.GetPointer() + fBegin;
+      char *p = fStr.GetPointer() + fBegin;
       Ssiz_t n = fExtent;
       while (n--) { *p = toupper((unsigned char)*p); p++;}
    }
@@ -2187,7 +2187,8 @@ TString TString::BaseConvert(const TString& s_in, Int_t base_in, Int_t base_out)
    if (!isSigned && s_in_[0] == '+') s_in_.Remove(0, 1);  // !isSigned to avoid strings beginning with "-+"
    if (base_in == 16 && s_in_.BeginsWith("0x")) s_in_.Remove(0, 2);  // removing hex prefix if any
    s_in_ = TString(s_in_.Strip(TString::kLeading, '0'));  // removing leading zeros (necessary for length comparison below)
-   // checking s_in_ is expressed in the mentionned base
+   if (!s_in_.Length()) s_in_ += '0';
+   // checking s_in_ is expressed in the mentioned base
    if (!s_in_.IsInBaseN(base_in)) {
       Error("TString::BaseConvert", "s_in=\"%s\" is not in base %d", s_in.Data(), base_in);
       return (s_out);
