@@ -39,7 +39,6 @@
 class TBaseClass;
 class TBrowser;
 class TDataMember;
-class TClassAttributeMap;
 class TClassRef;
 class TMethod;
 class TRealData;
@@ -84,6 +83,14 @@ public:
           kHasNameMapNode = BIT(22)
    };
    enum ENewType { kRealNew = 0, kClassNew, kDummyNew };
+   enum ECheckSum {
+      kCurrentCheckSum = 0,
+      kNoEnum          = 1, // Used since v3.3
+      kNoRange         = 2, // Up to v5.17
+      kWithTypeDef     = 3, // Up to v5.34.18 and v5.99/06
+      kNoBaseCheckSum  = 4, // Up to v5.34.18 and v5.99/06
+      kLatestCheckSum  = 5
+   };
 
 private:
 
@@ -140,7 +147,6 @@ private:
    TClassRef         *fRefStart;        //!List of references to this object
    TVirtualRefProxy  *fRefProxy;        //!Pointer to reference proxy if this class represents a reference
    ROOT::TSchemaRuleSet *fSchemaRules;  //! Schema evolution rules
-   TClassAttributeMap *fAttributeMap;    //pointer to a class attribute map  
 
    typedef void (TClass::*StreamerImpl_t)(void *obj, TBuffer &b, const TClass *onfile_class) const;
    mutable StreamerImpl_t fStreamerImpl;//! Pointer to the function implementing the right streaming behavior for the class represented by this object.
@@ -253,7 +259,7 @@ public:
    TVirtualStreamerInfo     *GetConversionStreamerInfo( const TClass* onfile_cl, Int_t version ) const;
    TVirtualStreamerInfo     *FindConversionStreamerInfo( const TClass* onfile_cl, UInt_t checksum ) const;
    Bool_t             HasDefaultConstructor() const;
-   UInt_t             GetCheckSum(UInt_t code=0) const;
+   UInt_t             GetCheckSum(ECheckSum code = kCurrentCheckSum) const;
    TVirtualCollectionProxy *GetCollectionProxy() const;
    TVirtualIsAProxy  *GetIsAProxy() const;
    Version_t          GetClassVersion() const { fVersionUsed = kTRUE; return fClassVersion; }
@@ -310,6 +316,7 @@ public:
    TObjArray         *GetStreamerInfos() const { return fStreamerInfo; }
    TVirtualStreamerInfo     *GetStreamerInfo(Int_t version=0) const;
    TVirtualStreamerInfo     *GetStreamerInfoAbstractEmulated(Int_t version=0) const;
+   TVirtualStreamerInfo     *FindStreamerInfoAbstractEmulated(UInt_t checksum) const;
    const type_info   *GetTypeInfo() const { return fTypeInfo; };
    void               IgnoreTObjectStreamer(Bool_t ignore=kTRUE);
    Bool_t             InheritsFrom(const char *cl) const;
@@ -319,9 +326,11 @@ public:
    Bool_t             IsLoaded() const;
    Bool_t             IsForeign() const;
    Bool_t             IsStartingWithTObject() const;
+   Bool_t             IsVersioned() const { return !( GetClassVersion()<=1 && IsForeign() ); }
    Bool_t             IsTObject() const;
    void               ls(Option_t *opt="") const;
    void               MakeCustomMenuList();
+   Bool_t             MatchLegacyCheckSum(UInt_t checksum) const;
    void               Move(void *arenaFrom, void *arenaTo) const;
    void              *New(ENewType defConstructor = kClassNew) const;
    void              *New(void *arena, ENewType defConstructor = kClassNew) const;
@@ -383,14 +392,6 @@ public:
    void               Destructor(void *obj, Bool_t dtorOnly = kFALSE);
    void              *DynamicCast(const TClass *base, void *obj, Bool_t up = kTRUE);
    Bool_t             IsFolder(void *obj) const;
-   void               CreateAttributeMap();
-   TClassAttributeMap *GetAttributeMap() const
-   {
-      //Get the TClassAttributeMap pointer to be able to add attribute 
-      //pairs key-value to the TClass.
- 
-      return fAttributeMap;
-   }
    inline void        Streamer(void *obj, TBuffer &b, const TClass *onfile_class = 0) const
    {
       // Inline for performance, skipping one function call.
