@@ -42,10 +42,32 @@
 #include "TClass.h"
 #include "TClassEdit.h"
 #include "TDataType.h"
+#include "TDictAttributeMap.h"
 #include "TROOT.h"
 
 ClassImp(TDictionary)
 
+TDictionary::TDictionary(const TDictionary& dict):
+   TNamed(dict),
+   fAttributeMap(dict.fAttributeMap ?
+                 ((TDictAttributeMap*)dict.fAttributeMap->Clone()) : 0 )
+{ }
+
+TDictionary::~TDictionary() {
+   if(fAttributeMap) {
+      delete fAttributeMap;
+   }
+}
+
+void TDictionary::CreateAttributeMap()
+{
+   //Create a TDictAttributeMap for a TClass to be able to add attribute pairs
+   //key-value to the TClass.
+
+   if (!fAttributeMap)
+      fAttributeMap = new TDictAttributeMap;
+}
+
 TDictionary* TDictionary::GetDictionary(const char* name)
 {
    // Retrieve the type (class, fundamental type, typedef etc)
