@@ -162,7 +162,7 @@ void TGeoCone::ComputeBBox()
 }
 
 //_____________________________________________________________________________
-void TGeoCone::ComputeNormal(Double_t *point, Double_t *dir, Double_t *norm)
+void TGeoCone::ComputeNormal(const Double_t *point, const Double_t *dir, Double_t *norm)
 {
 // Compute normal to closest surface from POINT.
    Double_t safr,safe,phi;
@@ -204,7 +204,7 @@ void TGeoCone::ComputeNormal(Double_t *point, Double_t *dir, Double_t *norm)
 }
 
 //_____________________________________________________________________________
-void TGeoCone::ComputeNormalS(Double_t *point, Double_t *dir, Double_t *norm,
+void TGeoCone::ComputeNormalS(const Double_t *point, const Double_t *dir, Double_t *norm,
                               Double_t dz, Double_t rmin1, Double_t rmax1, Double_t rmin2, Double_t rmax2)
 {
 // Compute normal to closest surface from POINT.
@@ -240,7 +240,7 @@ void TGeoCone::ComputeNormalS(Double_t *point, Double_t *dir, Double_t *norm,
 }
 
 //_____________________________________________________________________________
-Bool_t TGeoCone::Contains(Double_t *point) const
+Bool_t TGeoCone::Contains(const Double_t *point) const
 {
 // test if point is inside this cone
    if (TMath::Abs(point[2]) > fDz) return kFALSE;
@@ -252,7 +252,7 @@ Bool_t TGeoCone::Contains(Double_t *point) const
 }
 
 //_____________________________________________________________________________
-Double_t TGeoCone::DistFromInsideS(Double_t *point, Double_t *dir, Double_t dz,
+Double_t TGeoCone::DistFromInsideS(const Double_t *point, const Double_t *dir, Double_t dz,
                               Double_t rmin1, Double_t rmax1, Double_t rmin2, Double_t rmax2)
 {
 // Compute distance from inside point to surface of the cone (static)
@@ -323,7 +323,7 @@ Double_t TGeoCone::DistFromInsideS(Double_t *point, Double_t *dir, Double_t dz,
 }
 
 //_____________________________________________________________________________
-Double_t TGeoCone::DistFromInside(Double_t *point, Double_t *dir, Int_t iact, Double_t step, Double_t *safe) const
+Double_t TGeoCone::DistFromInside(const Double_t *point, const Double_t *dir, Int_t iact, Double_t step, Double_t *safe) const
 {
 // Compute distance from inside point to surface of the cone
 // Boundary safe algorithm.
@@ -338,7 +338,7 @@ Double_t TGeoCone::DistFromInside(Double_t *point, Double_t *dir, Int_t iact, Do
 }
 
 //_____________________________________________________________________________
-Double_t TGeoCone::DistFromOutsideS(Double_t *point, Double_t *dir, Double_t dz,
+Double_t TGeoCone::DistFromOutsideS(const Double_t *point, const Double_t *dir, Double_t dz,
                              Double_t rmin1, Double_t rmax1, Double_t rmin2, Double_t rmax2)
 {
 // Compute distance from outside point to surface of the tube
@@ -468,7 +468,7 @@ Double_t TGeoCone::DistFromOutsideS(Double_t *point, Double_t *dir, Double_t dz,
 }
 
 //_____________________________________________________________________________
-Double_t TGeoCone::DistFromOutside(Double_t *point, Double_t *dir, Int_t iact, Double_t step, Double_t *safe) const
+Double_t TGeoCone::DistFromOutside(const Double_t *point, const Double_t *dir, Int_t iact, Double_t step, Double_t *safe) const
 {
 // compute distance from outside point to surface of the tube
    // compute safe radius
@@ -485,7 +485,7 @@ Double_t TGeoCone::DistFromOutside(Double_t *point, Double_t *dir, Int_t iact, D
 }
 
 //_____________________________________________________________________________
-void TGeoCone::DistToCone(Double_t *point, Double_t *dir, Double_t dz, Double_t r1, Double_t r2,
+void TGeoCone::DistToCone(const Double_t *point, const Double_t *dir, Double_t dz, Double_t r1, Double_t r2,
                               Double_t &b, Double_t &delta)
 {
    // Static method to compute distance to a conical surface with :
@@ -832,7 +832,7 @@ void TGeoCone::SetSegsAndPols(TBuffer3D &buffer) const
 }
 
 //_____________________________________________________________________________
-Double_t TGeoCone::Safety(Double_t *point, Bool_t in) const
+Double_t TGeoCone::Safety(const Double_t *point, Bool_t in) const
 {
 // computes the closest distance from given point to this shape, according
 // to option. The matching point on the shape is stored in spoint.
@@ -846,7 +846,7 @@ Double_t TGeoCone::Safety(Double_t *point, Bool_t in) const
 }
 
 //_____________________________________________________________________________
-Double_t TGeoCone::SafetyS(Double_t *point, Bool_t in, Double_t dz, Double_t rmin1, Double_t rmax1,
+Double_t TGeoCone::SafetyS(const Double_t *point, Bool_t in, Double_t dz, Double_t rmin1, Double_t rmax1,
                            Double_t rmin2, Double_t rmax2, Int_t skipz)
 {
 // computes the closest distance from given point to this shape, according
@@ -1107,10 +1107,53 @@ const TBuffer3D & TGeoCone::GetBuffer3D(Int_t reqSections, Bool_t localFrame) co
    return buffer;
 }
 
+//_____________________________________________________________________________
+void TGeoCone::Contains_v(const Double_t *points, Bool_t *inside, Int_t vecsize) const
+{
+// Check the inside status for each of the points in the array.
+// Input: Array of point coordinates + vector size
+// Output: Array of Booleans for the inside of each point
+   for (Int_t i=0; i<vecsize; i++) inside[i] = Contains(&points[3*i]);
+}
+
+//_____________________________________________________________________________
+void TGeoCone::ComputeNormal_v(const Double_t *points, const Double_t *dirs, Double_t *norms, Int_t vecsize)
+{
+// Compute the normal for an array o points so that norm.dot.dir is positive
+// Input: Arrays of point coordinates and directions + vector size
+// Output: Array of normal directions
+   for (Int_t i=0; i<vecsize; i++) ComputeNormal(&points[3*i], &dirs[3*i], &norms[3*i]);
+}
+
+//_____________________________________________________________________________
+void TGeoCone::DistFromInside_v(const Double_t *points, const Double_t *dirs, Double_t *dists, Int_t vecsize, Double_t* step) const
+{
+// Compute distance from array of input points having directions specisied by dirs. Store output in dists
+   for (Int_t i=0; i<vecsize; i++) dists[i] = DistFromInside(&points[3*i], &dirs[3*i], 3, step[i]);
+}
+
+//_____________________________________________________________________________
+void TGeoCone::DistFromOutside_v(const Double_t *points, const Double_t *dirs, Double_t *dists, Int_t vecsize, Double_t* step) const
+{
+// Compute distance from array of input points having directions specisied by dirs. Store output in dists
+   for (Int_t i=0; i<vecsize; i++) dists[i] = DistFromOutside(&points[3*i], &dirs[3*i], 3, step[i]);
+}
+
+//_____________________________________________________________________________
+void TGeoCone::Safety_v(const Double_t *points, const Bool_t *inside, Double_t *safe, Int_t vecsize) const
+{
+// Compute safe distance from each of the points in the input array.
+// Input: Array of point coordinates, array of statuses for these points, size of the arrays
+// Output: Safety values
+   for (Int_t i=0; i<vecsize; i++) safe[i] = Safety(&points[3*i], inside[i]);
+}
+
 ClassImp(TGeoConeSeg)
 
 //_____________________________________________________________________________
 TGeoConeSeg::TGeoConeSeg()
+            :TGeoCone(),
+             fPhi1(0.), fPhi2(0.), fS1(0.), fC1(0.), fS2(0.), fC2(0.), fSm(0.), fCm(0.), fCdfi(0.)
 {
 // Default constructor
    SetShapeBit(TGeoShape::kGeoConeSeg);
@@ -1120,7 +1163,9 @@ TGeoConeSeg::TGeoConeSeg()
 //_____________________________________________________________________________
 TGeoConeSeg::TGeoConeSeg(Double_t dz, Double_t rmin1, Double_t rmax1,
                           Double_t rmin2, Double_t rmax2, Double_t phi1, Double_t phi2)
-            :TGeoCone(dz, rmin1, rmax1, rmin2, rmax2)
+            :TGeoCone(dz, rmin1, rmax1, rmin2, rmax2),
+             fPhi1(0.), fPhi2(0.), fS1(0.), fC1(0.), fS2(0.), fC2(0.), fSm(0.), fCm(0.), fCdfi(0.)
+            
 {
 // Default constructor specifying minimum and maximum radius
    SetShapeBit(TGeoShape::kGeoConeSeg);
@@ -1131,7 +1176,8 @@ TGeoConeSeg::TGeoConeSeg(Double_t dz, Double_t rmin1, Double_t rmax1,
 //_____________________________________________________________________________
 TGeoConeSeg::TGeoConeSeg(const char *name, Double_t dz, Double_t rmin1, Double_t rmax1,
                           Double_t rmin2, Double_t rmax2, Double_t phi1, Double_t phi2)
-            :TGeoCone(name, dz, rmin1, rmax1, rmin2, rmax2)
+            :TGeoCone(name, dz, rmin1, rmax1, rmin2, rmax2),
+             fPhi1(0.), fPhi2(0.), fS1(0.), fC1(0.), fS2(0.), fC2(0.), fSm(0.), fCm(0.), fCdfi(0.)
 {
 // Default constructor specifying minimum and maximum radius
    SetShapeBit(TGeoShape::kGeoConeSeg);
@@ -1141,7 +1187,8 @@ TGeoConeSeg::TGeoConeSeg(const char *name, Double_t dz, Double_t rmin1, Double_t
 
 //_____________________________________________________________________________
 TGeoConeSeg::TGeoConeSeg(Double_t *param)
-            :TGeoCone(0,0,0,0,0)
+            :TGeoCone(0,0,0,0,0),
+             fPhi1(0.), fPhi2(0.), fS1(0.), fC1(0.), fS2(0.), fC2(0.), fSm(0.), fCm(0.), fCdfi(0.)
 {
 // Default constructor specifying minimum and maximum radius
 // param[0] = dz
@@ -1162,6 +1209,30 @@ TGeoConeSeg::~TGeoConeSeg()
 // destructor
 }
 
+//_____________________________________________________________________________
+void TGeoConeSeg::AfterStreamer()
+{
+// Function called after streaming an object of this class.
+   InitTrigonometry();
+}   
+
+//_____________________________________________________________________________
+void TGeoConeSeg::InitTrigonometry()
+{
+// Init frequently used trigonometric values
+   Double_t phi1 = fPhi1*TMath::DegToRad();
+   Double_t phi2 = fPhi2*TMath::DegToRad();
+   fC1 = TMath::Cos(phi1);
+   fS1 = TMath::Sin(phi1);
+   fC2 = TMath::Cos(phi2);
+   fS2 = TMath::Sin(phi2);
+   Double_t fio = 0.5*(phi1+phi2);
+   fCm = TMath::Cos(fio);
+   fSm = TMath::Sin(fio);
+   Double_t dfi = 0.5*(phi2-phi1);
+   fCdfi = TMath::Cos(dfi);
+}
+
 //_____________________________________________________________________________
 Double_t TGeoConeSeg::Capacity() const
 {
@@ -1189,14 +1260,14 @@ void TGeoConeSeg::ComputeBBox()
 
    Double_t xc[4];
    Double_t yc[4];
-   xc[0] = rmax*TMath::Cos(fPhi1*TMath::DegToRad());
-   yc[0] = rmax*TMath::Sin(fPhi1*TMath::DegToRad());
-   xc[1] = rmax*TMath::Cos(fPhi2*TMath::DegToRad());
-   yc[1] = rmax*TMath::Sin(fPhi2*TMath::DegToRad());
-   xc[2] = rmin*TMath::Cos(fPhi1*TMath::DegToRad());
-   yc[2] = rmin*TMath::Sin(fPhi1*TMath::DegToRad());
-   xc[3] = rmin*TMath::Cos(fPhi2*TMath::DegToRad());
-   yc[3] = rmin*TMath::Sin(fPhi2*TMath::DegToRad());
+   xc[0] = rmax*fC1;
+   yc[0] = rmax*fS1;
+   xc[1] = rmax*fC2;
+   yc[1] = rmax*fS2;
+   xc[2] = rmin*fC1;
+   yc[2] = rmin*fS1;
+   xc[3] = rmin*fC2;
+   yc[3] = rmin*fS2;
 
    Double_t xmin = xc[TMath::LocMin(4, &xc[0])];
    Double_t xmax = xc[TMath::LocMax(4, &xc[0])];
@@ -1225,7 +1296,7 @@ void TGeoConeSeg::ComputeBBox()
 }
 
 //_____________________________________________________________________________
-void TGeoConeSeg::ComputeNormal(Double_t *point, Double_t *dir, Double_t *norm)
+void TGeoConeSeg::ComputeNormal(const Double_t *point, const Double_t *dir, Double_t *norm)
 {
 // Compute normal to closest surface from POINT.
    Double_t saf[3];
@@ -1236,11 +1307,6 @@ void TGeoConeSeg::ComputeNormal(Double_t *point, Double_t *dir, Double_t *norm)
    Double_t tg2 = 0.5*(fRmax2-fRmax1)/fDz;
    Double_t cr2 = 1./TMath::Sqrt(1.+tg2*tg2);
 
-   Double_t c1 = TMath::Cos(fPhi1*TMath::DegToRad());
-   Double_t s1 = TMath::Sin(fPhi1*TMath::DegToRad());
-   Double_t c2 = TMath::Cos(fPhi2*TMath::DegToRad());
-   Double_t s2 = TMath::Sin(fPhi2*TMath::DegToRad());
-
    Double_t r=TMath::Sqrt(point[0]*point[0]+point[1]*point[1]);
    Double_t rin = tg1*point[2]+ro1;
    Double_t rout = tg2*point[2]+ro2;
@@ -1248,8 +1314,8 @@ void TGeoConeSeg::ComputeNormal(Double_t *point, Double_t *dir, Double_t *norm)
    saf[1] = (ro1>0)?(TMath::Abs((r-rin)*cr1)):TGeoShape::Big();
    saf[2] = TMath::Abs((rout-r)*cr2);
    Int_t i = TMath::LocMin(3,saf);
-   if (((fPhi2-fPhi1)<360.) && TGeoShape::IsCloseToPhi(saf[i], point,c1,s1,c2,s2)) {
-      TGeoShape::NormalPhi(point,dir,norm,c1,s1,c2,s2);
+   if (((fPhi2-fPhi1)<360.) && TGeoShape::IsCloseToPhi(saf[i], point,fC1,fS1,fC2,fS2)) {
+      TGeoShape::NormalPhi(point,dir,norm,fC1,fS1,fC2,fS2);
       return;
    }
    if (i==0) {
@@ -1280,7 +1346,7 @@ void TGeoConeSeg::ComputeNormal(Double_t *point, Double_t *dir, Double_t *norm)
 }
 
 //_____________________________________________________________________________
-void TGeoConeSeg::ComputeNormalS(Double_t *point, Double_t *dir, Double_t *norm,
+void TGeoConeSeg::ComputeNormalS(const Double_t *point, const Double_t *dir, Double_t *norm,
                                  Double_t dz, Double_t rmin1, Double_t rmax1, Double_t rmin2, Double_t rmax2,
                                  Double_t c1, Double_t s1, Double_t c2, Double_t s2)
 {
@@ -1326,7 +1392,7 @@ void TGeoConeSeg::ComputeNormalS(Double_t *point, Double_t *dir, Double_t *norm,
 }
 
 //_____________________________________________________________________________
-Bool_t TGeoConeSeg::Contains(Double_t *point) const
+Bool_t TGeoConeSeg::Contains(const Double_t *point) const
 {
 // test if point is inside this sphere
    if (!TGeoCone::Contains(point)) return kFALSE;
@@ -1342,7 +1408,7 @@ Bool_t TGeoConeSeg::Contains(Double_t *point) const
 }
 
 //_____________________________________________________________________________
-Double_t TGeoConeSeg::DistToCons(Double_t *point, Double_t *dir, Double_t r1, Double_t z1, Double_t r2, Double_t z2, Double_t phi1, Double_t phi2)
+Double_t TGeoConeSeg::DistToCons(const Double_t *point, const Double_t *dir, Double_t r1, Double_t z1, Double_t r2, Double_t z2, Double_t phi1, Double_t phi2)
 {
    // Static method to compute distance to a conical surface with :
    // - r1, z1 - radius and Z position of lower base
@@ -1416,7 +1482,7 @@ Double_t TGeoConeSeg::DistToCons(Double_t *point, Double_t *dir, Double_t r1, Do
 }
 
 //_____________________________________________________________________________
-Double_t TGeoConeSeg::DistFromInsideS(Double_t *point, Double_t *dir, Double_t dz, 
+Double_t TGeoConeSeg::DistFromInsideS(const Double_t *point, const Double_t *dir, Double_t dz, 
                        Double_t rmin1, Double_t rmax1, Double_t rmin2, Double_t rmax2, 
                        Double_t c1, Double_t s1, Double_t c2, Double_t s2, Double_t cm, Double_t sm, Double_t cdfi)
 {
@@ -1465,7 +1531,7 @@ Double_t TGeoConeSeg::DistFromInsideS(Double_t *point, Double_t *dir, Double_t d
 }
 
 //_____________________________________________________________________________
-Double_t TGeoConeSeg::DistFromInside(Double_t *point, Double_t *dir, Int_t iact, Double_t step, Double_t *safe) const
+Double_t TGeoConeSeg::DistFromInside(const Double_t *point, const Double_t *dir, Int_t iact, Double_t step, Double_t *safe) const
 {
 // compute distance from inside point to surface of the tube segment
    if (iact<3 && safe) {
@@ -1474,24 +1540,13 @@ Double_t TGeoConeSeg::DistFromInside(Double_t *point, Double_t *dir, Int_t iact,
       if ((iact==1) && (*safe>step)) return TGeoShape::Big();
    }
    if ((fPhi2-fPhi1)>=360.) return TGeoCone::DistFromInsideS(point,dir,fDz,fRmin1,fRmax1,fRmin2,fRmax2);
-   Double_t phi1 = fPhi1*TMath::DegToRad();
-   Double_t phi2 = fPhi2*TMath::DegToRad();
-   Double_t c1 = TMath::Cos(phi1);
-   Double_t c2 = TMath::Cos(phi2);
-   Double_t s1 = TMath::Sin(phi1);
-   Double_t s2 = TMath::Sin(phi2);
-   Double_t phim = 0.5*(phi1+phi2);
-   Double_t cm = TMath::Cos(phim);
-   Double_t sm = TMath::Sin(phim);
-   Double_t dfi = 0.5*(phi2-phi1);
-   Double_t cdfi = TMath::Cos(dfi);
 
    // compute distance to surface
-   return TGeoConeSeg::DistFromInsideS(point,dir,fDz,fRmin1,fRmax1,fRmin2,fRmax2,c1,s1,c2,s2,cm,sm,cdfi);
+   return TGeoConeSeg::DistFromInsideS(point,dir,fDz,fRmin1,fRmax1,fRmin2,fRmax2,fC1,fS1,fC2,fS2,fCm,fSm,fCdfi);
 }
 
 //_____________________________________________________________________________
-Double_t TGeoConeSeg::DistFromOutsideS(Double_t *point, Double_t *dir, Double_t dz, 
+Double_t TGeoConeSeg::DistFromOutsideS(const Double_t *point, const Double_t *dir, Double_t dz, 
                        Double_t rmin1, Double_t rmax1, Double_t rmin2, Double_t rmax2, 
                        Double_t c1, Double_t s1, Double_t c2, Double_t s2, Double_t cm, Double_t sm, Double_t cdfi)
 {
@@ -1765,7 +1820,7 @@ Double_t TGeoConeSeg::DistFromOutsideS(Double_t *point, Double_t *dir, Double_t
 }
 
 //_____________________________________________________________________________
-Double_t TGeoConeSeg::DistFromOutside(Double_t *point, Double_t *dir, Int_t iact, Double_t step, Double_t *safe) const
+Double_t TGeoConeSeg::DistFromOutside(const Double_t *point, const Double_t *dir, Int_t iact, Double_t step, Double_t *safe) const
 {
 // compute distance from outside point to surface of the tube
    // compute safe radius
@@ -1778,18 +1833,7 @@ Double_t TGeoConeSeg::DistFromOutside(Double_t *point, Double_t *dir, Int_t iact
    Double_t sdist = TGeoBBox::DistFromOutside(point,dir, fDX, fDY, fDZ, fOrigin, step);
    if (sdist>=step) return TGeoShape::Big();
    if ((fPhi2-fPhi1)>=360.) return TGeoCone::DistFromOutsideS(point,dir,fDz,fRmin1,fRmax1,fRmin2,fRmax2);
-   Double_t phi1 = fPhi1*TMath::DegToRad();
-   Double_t phi2 = fPhi2*TMath::DegToRad();
-   Double_t c1 = TMath::Cos(phi1);
-   Double_t c2 = TMath::Cos(phi2);
-   Double_t s1 = TMath::Sin(phi1);
-   Double_t s2 = TMath::Sin(phi2);
-   Double_t phim = 0.5*(phi1+phi2);
-   Double_t cm = TMath::Cos(phim);
-   Double_t sm = TMath::Sin(phim);
-   Double_t dfi = 0.5*(phi2-phi1);
-   Double_t cdfi = TMath::Cos(dfi);
-   return TGeoConeSeg::DistFromOutsideS(point,dir,fDz,fRmin1,fRmax1,fRmin2,fRmax2,c1,s1,c2,s2,cm,sm,cdfi);
+   return TGeoConeSeg::DistFromOutsideS(point,dir,fDz,fRmin1,fRmax1,fRmin2,fRmax2,fC1,fS1,fC2,fS2,fCm,fSm,fCdfi);
 }
 
 //_____________________________________________________________________________
@@ -2054,7 +2098,7 @@ void TGeoConeSeg::SetSegsAndPols(TBuffer3D &buffer) const
 }
 
 //_____________________________________________________________________________
-Double_t TGeoConeSeg::Safety(Double_t *point, Bool_t in) const
+Double_t TGeoConeSeg::Safety(const Double_t *point, Bool_t in) const
 {
 // computes the closest distance from given point to this shape, according
 // to option. The matching point on the shape is stored in spoint.
@@ -2068,7 +2112,7 @@ Double_t TGeoConeSeg::Safety(Double_t *point, Bool_t in) const
 }
 
 //_____________________________________________________________________________
-Double_t TGeoConeSeg::SafetyS(Double_t *point, Bool_t in, Double_t dz, Double_t rmin1, Double_t rmax1,
+Double_t TGeoConeSeg::SafetyS(const Double_t *point, Bool_t in, Double_t dz, Double_t rmin1, Double_t rmax1,
                               Double_t rmin2, Double_t rmax2, Double_t phi1, Double_t phi2, Int_t skipz)
 {
 // Static method to compute the closest distance from given point to this shape.
@@ -2111,7 +2155,8 @@ void TGeoConeSeg::SetConsDimensions(Double_t dz, Double_t rmin1, Double_t rmax1,
    while (fPhi1<0) fPhi1+=360.;
    fPhi2 = phi2;
    while (fPhi2<=fPhi1) fPhi2+=360.;
-   if (TGeoShape::IsSameWithinTolerance(fPhi1,fPhi2)) Error("SetConsDimensions", "In shape %s invalid phi1=%g, phi2=%g\n", GetName(), fPhi1, fPhi2);
+   if (TGeoShape::IsSameWithinTolerance(fPhi1,fPhi2)) Fatal("SetConsDimensions", "In shape %s invalid phi1=%g, phi2=%g\n", GetName(), fPhi1, fPhi2);
+   InitTrigonometry();
 }
 
 //_____________________________________________________________________________
@@ -2323,3 +2368,44 @@ Bool_t TGeoConeSeg::GetPointsOnSegments(Int_t npoints, Double_t *array) const
    }
    return kTRUE;
 }                    
+
+//_____________________________________________________________________________
+void TGeoConeSeg::Contains_v(const Double_t *points, Bool_t *inside, Int_t vecsize) const
+{
+// Check the inside status for each of the points in the array.
+// Input: Array of point coordinates + vector size
+// Output: Array of Booleans for the inside of each point
+   for (Int_t i=0; i<vecsize; i++) inside[i] = Contains(&points[3*i]);
+}
+
+//_____________________________________________________________________________
+void TGeoConeSeg::ComputeNormal_v(const Double_t *points, const Double_t *dirs, Double_t *norms, Int_t vecsize)
+{
+// Compute the normal for an array o points so that norm.dot.dir is positive
+// Input: Arrays of point coordinates and directions + vector size
+// Output: Array of normal directions
+   for (Int_t i=0; i<vecsize; i++) ComputeNormal(&points[3*i], &dirs[3*i], &norms[3*i]);
+}
+
+//_____________________________________________________________________________
+void TGeoConeSeg::DistFromInside_v(const Double_t *points, const Double_t *dirs, Double_t *dists, Int_t vecsize, Double_t* step) const
+{
+// Compute distance from array of input points having directions specisied by dirs. Store output in dists
+   for (Int_t i=0; i<vecsize; i++) dists[i] = DistFromInside(&points[3*i], &dirs[3*i], 3, step[i]);
+}
+
+//_____________________________________________________________________________
+void TGeoConeSeg::DistFromOutside_v(const Double_t *points, const Double_t *dirs, Double_t *dists, Int_t vecsize, Double_t* step) const
+{
+// Compute distance from array of input points having directions specisied by dirs. Store output in dists
+   for (Int_t i=0; i<vecsize; i++) dists[i] = DistFromOutside(&points[3*i], &dirs[3*i], 3, step[i]);
+}
+
+//_____________________________________________________________________________
+void TGeoConeSeg::Safety_v(const Double_t *points, const Bool_t *inside, Double_t *safe, Int_t vecsize) const
+{
+// Compute safe distance from each of the points in the input array.
+// Input: Array of point coordinates, array of statuses for these points, size of the arrays
+// Output: Safety values
+   for (Int_t i=0; i<vecsize; i++) safe[i] = Safety(&points[3*i], inside[i]);
+}
