@@ -539,8 +539,10 @@ void TCanvas::Build()
       fCanvasID = fCanvasImp->InitWindow();
    if (fCanvasID == -1) return;
 
-   if (fCw < fCh) fXsizeReal = fYsizeReal*Float_t(fCw)/Float_t(fCh);
-   else           fYsizeReal = fXsizeReal*Float_t(fCh)/Float_t(fCw);
+   if (fCw !=0 && fCh !=0) {
+      if (fCw < fCh) fXsizeReal = fYsizeReal*Float_t(fCw)/Float_t(fCh);
+      else           fYsizeReal = fXsizeReal*Float_t(fCh)/Float_t(fCw);
+   }
 
    // Set Pad parameters
    gPad            = this;
@@ -648,6 +650,8 @@ void TCanvas::Destructor()
 
    Close();
 
+   //In a batch mode fPainter can be non-null after
+   //the call to Close above (???)
    delete fPainter;
 }
 
@@ -749,9 +753,8 @@ void TCanvas::Close(Option_t *option)
 
    if (!IsBatch()) {
       gVirtualX->SelectWindow(fCanvasID);    //select current canvas
-
-      if (fGLDevice != -1)
-         gGLManager->DeleteGLContext(fGLDevice);//?
+      
+      DeleteCanvasPainter();
 
       if (fCanvasImp) fCanvasImp->Close();
    }
@@ -1173,7 +1176,7 @@ void TCanvas::HandleInput(EEventType event, Int_t px, Int_t py)
       // mouse enters canvas
       if (!fDoubleBuffer) FeedbackMode(kTRUE);
       break;
-
+      
    case kMouseLeave:
       // mouse leaves canvas
       {
@@ -1210,6 +1213,8 @@ void TCanvas::HandleInput(EEventType event, Int_t px, Int_t py)
 
       break;
 
+   case kArrowKeyPress:
+   case kArrowKeyRelease:
    case kButton1Motion:
    case kButton1ShiftMotion: //8 == kButton1Motion + shift modifier
       if (fSelected) {
@@ -2098,6 +2103,18 @@ void TCanvas::ToggleToolTips()
    if (fCanvasImp) fCanvasImp->ShowToolTips(showToolTips);
 }
 
+
+//______________________________________________________________________________
+Bool_t TCanvas::SupportAlpha()
+{
+   // Static function returning "true" if transparency is supported.
+   //gPad must exist (otherwise this call has no sense), and
+   //either it's a gl-pad or we are on OS X with --enable-cocoa.
+   return gPad && (gVirtualX->InheritsFrom("TGQuartz") ||
+                   gPad->GetGLDevice() != -1);
+}
+
+
 //______________________________________________________________________________
 void TCanvas::Update()
 {
@@ -2191,3 +2208,25 @@ TVirtualPadPainter *TCanvas::GetCanvasPainter()
    if (!fPainter) CreatePainter();
    return fPainter;
 }
+
+//______________________________________________________________________________
+void TCanvas::DeleteCanvasPainter()
+{
+   //assert on IsBatch() == false?
+   
+   if (fGLDevice != -1) {
+      //fPainter has a font manager.
+      //Font manager will delete textures.
+      //If context is wrong (we can have several canvases) -
+      //wrong texture will be deleted, damaging some of our fonts.
+      gGLManager->MakeCurrent(fGLDevice);
+   }
+   
+   delete fPainter;
+   fPainter = 0;
+   
+   if (fGLDevice != -1) {
+      gGLManager->DeleteGLContext(fGLDevice);//?
+      fGLDevice = -1;
+   }
+}
