@@ -1586,10 +1586,11 @@ TLatexFormSize TLatex::Analyse(Double_t x, Double_t y, TextSpec_t spec, const Ch
             Analyse(x+GetHeight()*spec.fSize/2,y,spec,text+opSqrt+6,length-opSqrt-7);
 
             Short_t lineW = GetLineWidth();
+            SetLineWidth(0.);
             Double_t dx = (y2-y3)/8;
-            SetLineWidth(TMath::Max(2,(Int_t)(dx/2)));
+            if (spec.fSize>0.04) SetLineWidth(TMath::Max(2,(Int_t)(dx/2)));
             DrawLine(x1-2*dx,y1,x1-dx,y2,spec);
-            SetLineWidth((Int_t)(dx/4));
+            if (spec.fSize>0.04) SetLineWidth((Int_t)(dx/4));
             DrawLine(x1-dx,y2,x1,y3,spec);
             DrawLine(x1,y3,x2,y3,spec);
             SetLineWidth(lineW);
@@ -2020,6 +2021,7 @@ void TLatex::PaintLatex(Double_t x, Double_t y, Double_t angle, Double_t size, c
             t.ReplaceAll("#topbar","?");
             t.ReplaceAll("#arcbar","?");
             t.ReplaceAll("#downleftarrow","?");
+            t.ReplaceAll("#splitline","\\genfrac{}{}{0pt}{}");
 
             t.ReplaceAll("#","\\");
             t.ReplaceAll("%","\\%");
@@ -2042,6 +2044,7 @@ void TLatex::PaintLatex(Double_t x, Double_t y, Double_t angle, Double_t size, c
    if (strstr(text1,"\\")) {
       TMathText tm;
       tm.SetTextAlign(GetTextAlign());
+      tm.SetTextFont(GetTextFont());
       tm.PaintMathText(x, y, angle, size, text1);
       if (saveps) gVirtualPS = saveps;
       return;
@@ -2089,6 +2092,7 @@ void TLatex::PaintLatex(Double_t x, Double_t y, Double_t angle, Double_t size, c
    // Get current line attributes.
    Short_t lineW = GetLineWidth();
    Int_t lineC = GetLineColor();
+   if (size<0.04) SetLineWidth(0.);
 
    TextSpec_t spec;
    spec.fAngle = angle;
