@@ -79,7 +79,7 @@ TText::~TText()
 
 
 //______________________________________________________________________________
-TText::TText(const TText &text) : TNamed(text), TAttText(text)
+TText::TText(const TText &text) : TNamed(text), TAttText(text), TAttBBox2D(text)
 {
    // Copy constructor.
 
@@ -112,7 +112,7 @@ void TText::Copy(TObject &obj) const
 //______________________________________________________________________________
 const void *TText::GetWcsTitle(void) const
 {
-   // Returns teh text as UNICODE.
+   // Returns the text as UNICODE.
 
    if (fWcsTitle != NULL) {
       return reinterpret_cast<std::wstring *>(fWcsTitle)->c_str();
@@ -148,7 +148,7 @@ Int_t TText::DistancetoPrimitive(Int_t px, Int_t py)
    cBoxX[4] = cBoxX[0];
 
    // Check if the point (px,py) is inside the text control box
-   if(TMath::IsInside(px, py, 5, cBoxX, cBoxY)){
+   if (TMath::IsInside(px, py, 5, cBoxX, cBoxY)){
       return 0;
    } else {
       return 9999;
@@ -234,9 +234,12 @@ void TText::ExecuteEvent(Int_t event, Int_t px, Int_t py)
    Double_t dpx,dpy,xp1,yp1;
    Int_t cBoxX[4], cBoxY[4], part;
    Double_t div = 0;
+   Bool_t opaque  = gPad->OpaqueMoving();
+
    if (!gPad->IsEditable()) return;
    switch (event) {
 
+   case kArrowKeyPress:
    case kButton1Down:
       // No break !!!
 
@@ -290,8 +293,9 @@ void TText::ExecuteEvent(Int_t event, Int_t px, Int_t py)
       }
       break;
 
+   case kArrowKeyRelease:
    case kButton1Motion:
-      PaintControlBox(px1, py1, -theta);
+      if (!opaque) PaintControlBox(px1, py1, -theta);
       if (turn) {
          norm = TMath::Sqrt(Double_t((py-py1)*(py-py1)+(px-px1)*(px-px1)));
          if (norm>0) {
@@ -344,23 +348,37 @@ void TText::ExecuteEvent(Int_t event, Int_t px, Int_t py)
          dx = px - pxold;  px1 += dx;
          dy = py - pyold;  py1 += dy;
       }
-      PaintControlBox(px1, py1, -theta);
+      if (opaque) {
+         this->SetX(gPad->PadtoX(gPad->AbsPixeltoX(px1)));
+         this->SetY(gPad->PadtoY(gPad->AbsPixeltoY(py1)));
+         if (resize) gPad->ShowGuidelines(this, event, 't', false);
+         if ((!resize)&&(!turn)) gPad->ShowGuidelines(this, event, 'i', true);
+         gPad->ShowGuidelines(this, event, !resize&!turn);
+         this->SetTextAngle(theta);
+         gPad->Modified(kTRUE);
+         gPad->Update();
+      }
+      if (!opaque) PaintControlBox(px1, py1, -theta);
       pxold = px;  pyold = py;
       break;
 
    case kButton1Up:
-      if (TestBit(kTextNDC)) {
-         dpx  = gPad->GetX2() - gPad->GetX1();
-         dpy  = gPad->GetY2() - gPad->GetY1();
-         xp1  = gPad->GetX1();
-         yp1  = gPad->GetY1();
-         fX = (gPad->AbsPixeltoX(px1)-xp1)/dpx;
-         fY = (gPad->AbsPixeltoY(py1)-yp1)/dpy;
+      if (opaque) {
+         gPad->ShowGuidelines(this, event, !resize&!turn);
       } else {
-         fX = gPad->PadtoX(gPad->AbsPixeltoX(px1));
-         fY = gPad->PadtoY(gPad->AbsPixeltoY(py1));
+         if (TestBit(kTextNDC)) {
+            dpx  = gPad->GetX2() - gPad->GetX1();
+            dpy  = gPad->GetY2() - gPad->GetY1();
+            xp1  = gPad->GetX1();
+            yp1  = gPad->GetY1();
+            fX = (gPad->AbsPixeltoX(px1)-xp1)/dpx;
+            fY = (gPad->AbsPixeltoY(py1)-yp1)/dpy;
+         } else {
+            fX = gPad->PadtoX(gPad->AbsPixeltoX(px1));
+            fY = gPad->PadtoY(gPad->AbsPixeltoY(py1));
+         }
+         fTextAngle = theta;
       }
-      fTextAngle = theta;
       gPad->Modified(kTRUE);
       break;
 
@@ -473,7 +491,12 @@ void TText::GetBoundingBox(UInt_t &w, UInt_t &h, Bool_t angle)
       if ((gVirtualX->HasTTFonts() && TTF::IsInitialized()) || gPad->IsBatch()) {
          TTF::GetTextExtent(w, h, (char*)GetTitle());
       } else {
+         const Font_t oldFont = gVirtualX->GetTextFont();
+         if (gVirtualX->InheritsFrom("TGCocoa"))
+            gVirtualX->SetTextFont(fTextFont);
          gVirtualX->GetTextExtent(w, h, (char*)GetTitle());
+         if (gVirtualX->InheritsFrom("TGCocoa"))
+            gVirtualX->SetTextFont(oldFont);
       }
    }
 }
@@ -498,13 +521,18 @@ void TText::GetTextAscentDescent(UInt_t &a, UInt_t &d, const char *text) const
       a = TTF::GetBox().yMax;
       d = TMath::Abs(TTF::GetBox().yMin);
    } else {
+      const Font_t oldFont = gVirtualX->GetTextFont();
+      if (gVirtualX->InheritsFrom("TGCocoa"))
+         gVirtualX->SetTextFont(fTextFont);
       gVirtualX->SetTextSize((int)tsize);
-      a = gVirtualX->GetFontAscent();
+      a = gVirtualX->GetFontAscent(text);
       if (!a) {
          UInt_t w;
          gVirtualX->GetTextExtent(w, a, (char*)text);
       }
-      d = gVirtualX->GetFontDescent();
+      d = gVirtualX->GetFontDescent(text);
+      if (gVirtualX->InheritsFrom("TGCocoa"))
+         gVirtualX->SetTextFont(oldFont);
    }
 }
 
@@ -557,8 +585,13 @@ void TText::GetTextExtent(UInt_t &w, UInt_t &h, const char *text) const
       TTF::SetTextSize(tsize);
       TTF::GetTextExtent(w, h, (char*)text);
    } else {
+      const Font_t oldFont = gVirtualX->GetTextFont();
+      if (gVirtualX->InheritsFrom("TGCocoa"))
+         gVirtualX->SetTextFont(fTextFont);
       gVirtualX->SetTextSize((int)tsize);
       gVirtualX->GetTextExtent(w, h, (char*)text);
+      if (gVirtualX->InheritsFrom("TGCocoa"))
+         gVirtualX->SetTextFont(oldFont);
    }
 }
 
@@ -818,3 +851,106 @@ void TText::Streamer(TBuffer &R__b)
       R__b.WriteClassBuffer(TText::Class(),this);
    }
 }
+
+//______________________________________________________________________________
+Rectangle_t TText::GetBBox()
+{
+   // Return the "bounding Box" of the Box
+
+   UInt_t w, h;
+   Int_t Dx, Dy;
+   Dx = Dy = 0;
+   GetBoundingBox(w, h, false);
+
+   Short_t halign = fTextAlign/10;
+   Short_t valign = fTextAlign - 10*halign;
+
+   switch (halign) {
+      case 1 : Dx = 0      ; break;
+      case 2 : Dx = w/2   ; break;
+      case 3 : Dx = w     ; break;
+   }
+   switch (valign) {
+      case 1 : Dy = h     ; break;
+      case 2 : Dy = h/2   ; break;
+      case 3 : Dy = 0      ; break;
+   }
+
+   Rectangle_t BBox;
+   BBox.fX = gPad->XtoPixel(fX)-Dx;
+   BBox.fY = gPad->YtoPixel(fY)-Dy;
+   BBox.fWidth  = w;
+   BBox.fHeight = h;
+   return (BBox);
+}
+
+//______________________________________________________________________________
+TPoint TText::GetBBoxCenter()
+{
+   // Return the point given by Alignment as 'center'
+
+   TPoint p;
+   p.SetX(gPad->XtoPixel(fX));
+   p.SetY(gPad->YtoPixel(fY));
+   return(p);
+}
+
+//______________________________________________________________________________
+void TText::SetBBoxCenter(const TPoint &p)
+{
+   // Set the point given by Alignment as 'center'
+
+   this->SetX(gPad->PixeltoX(p.GetX()));
+   this->SetY(gPad->PixeltoY(p.GetY()-gPad->VtoPixel(0)));
+}
+
+//______________________________________________________________________________
+void TText::SetBBoxCenterX(const Int_t x)
+{
+   // Set X coordinate of the point given by Alignment as 'center'
+
+   this->SetX(gPad->PixeltoX(x));
+}
+
+//______________________________________________________________________________
+void TText::SetBBoxCenterY(const Int_t y)
+{
+   // Set Y coordinate of the point given by Alignment as 'center'
+
+   this->SetY(gPad->PixeltoY(y - gPad->VtoPixel(0)));
+}
+
+//______________________________________________________________________________
+void TText::SetBBoxX1(const Int_t /*x*/)
+{
+   // Set lefthandside of BoundingBox to a value
+   // (resize in x direction on left)
+
+   //NOT IMPLEMENTED
+}
+
+//______________________________________________________________________________
+void TText::SetBBoxX2(const Int_t /*x*/)
+{
+   // Set righthandside of BoundingBox to a value
+   // (resize in x direction on right)
+
+   //NOT IMPLEMENTED
+}
+
+//_______________________________________________________________________________
+void TText::SetBBoxY1(const Int_t /*y*/)
+{
+   // Set top of BoundingBox to a value (resize in y direction on top)
+
+   //NOT IMPLEMENTED
+}
+
+//_______________________________________________________________________________
+void TText::SetBBoxY2(const Int_t /*y*/)
+{
+   // Set bottom of BoundingBox to a value
+   // (resize in y direction on bottom)
+
+   //NOT IMPLEMENTED
+}
