@@ -16,7 +16,7 @@
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 // 02110-1301 USA
 
-#include "fontembed.h"
+#include "../inc/fontembed.h"
 #include <algorithm>
 #include <string.h>
 #include <stdio.h>
