@@ -60,6 +60,9 @@
 #include "TError.h"
 #include "TGDNDManager.h"
 #include "TBufferFile.h"
+#include "TRootBrowser.h"
+#include "TGTab.h"
+#include "TGedEditor.h"
 
 #include "TPluginManager.h"
 #include "TVirtualGL.h"
@@ -159,9 +162,9 @@ static const char *gOpenTypes[] = { "ROOT files",   "*.root",
                                     "All files",    "*",
                                     0,              0 };
 
-static const char *gSaveAsTypes[] = { "PostScript",   "*.ps",
+static const char *gSaveAsTypes[] = { "PDF",          "*.pdf",
+                                      "PostScript",   "*.ps",
                                       "Encapsulated PostScript", "*.eps",
-                                      "PDF",          "*.pdf",
                                       "SVG",          "*.svg",
                                       "TeX",          "*.tex",
                                       "GIF",          "*.gif",
@@ -329,6 +332,7 @@ void TRootCanvas::CreateCanvas(const char *name)
    fButton    = 0;
    fAutoFit   = kTRUE;   // check also menu entry
    fEditor    = 0;
+   fEmbedded  = kFALSE;
 
    // Create menus
    fFileSaveMenu = new TGPopupMenu(fClient->GetDefaultRoot());
@@ -524,6 +528,8 @@ void TRootCanvas::CreateCanvas(const char *name)
          TString x = "win32";
          if (gVirtualX->InheritsFrom("TGX11"))
             x = "x11";
+         else if (gVirtualX->InheritsFrom("TGCocoa"))
+            x = "osx";
 
          TPluginHandler *ph = gROOT->GetPluginManager()->FindHandler("TGLManager", x);
 
@@ -608,7 +614,7 @@ TRootCanvas::~TRootCanvas()
 
    delete fToolTip;
    if (fIconPic) gClient->FreePicture(fIconPic);
-   if (fEditor) delete fEditor;
+   if (fEditor && !fEmbedded) delete fEditor;
    if (fToolBar) {
       Disconnect(fToolDock, "Docked()",   this, "AdjustSize()");
       Disconnect(fToolDock, "Undocked()", this, "AdjustSize()");
@@ -656,8 +662,13 @@ void TRootCanvas::Close()
 {
    // Called via TCanvasImp interface by TCanvas.
    TVirtualPadEditor* gged = TVirtualPadEditor::GetPadEditor(kFALSE);
-   if(gged && gged->GetCanvas() == fCanvas)
-      gged->Hide();
+   if(gged && gged->GetCanvas() == fCanvas) {
+      if (fEmbedded) {
+         ((TGedEditor *)gged)->SetModel(0, 0, kButton1Down);
+         ((TGedEditor *)gged)->SetCanvas(0);
+      }
+      else gged->Hide();
+   }
 
    gVirtualX->CloseWindow();
 }
@@ -668,8 +679,13 @@ void TRootCanvas::ReallyDelete()
    // Really delete the canvas and this GUI.
 
    TVirtualPadEditor* gged = TVirtualPadEditor::GetPadEditor(kFALSE);
-   if(gged && gged->GetCanvas() == fCanvas)
-      gged->Hide();
+   if(gged && gged->GetCanvas() == fCanvas) {
+      if (fEmbedded) {
+         ((TGedEditor *)gged)->SetModel(0, 0, kButton1Down);
+         ((TGedEditor *)gged)->SetCanvas(0);
+      }
+      else gged->Hide();
+   }
 
    fToolTip->Hide();
    Disconnect(fCanvas, "ProcessedEvent(Int_t, Int_t, Int_t, TObject*)",
@@ -823,6 +839,16 @@ Bool_t TRootCanvas::ProcessMessage(Long_t msg, Long_t parm1, Long_t)
                         static Int_t typeidx = 0;
                         static Bool_t overwr = kFALSE;
                         TGFileInfo fi;
+                        TString defaultType = gEnv->GetValue("Canvas.SaveAsDefaultType", ".pdf");
+                        if (typeidx == 0) {
+                           for (int i=1;gSaveAsTypes[i];i+=2) {
+                              TString ftype = gSaveAsTypes[i];
+                              if (ftype.EndsWith(defaultType.Data())) {
+                                 typeidx = i-1;
+                                 break;
+                              }
+                           }
+                        }
                         fi.fFileTypes   = gSaveAsTypes;
                         fi.fIniDir      = StrDup(dir);
                         fi.fFileTypeIdx = typeidx;
@@ -863,6 +889,14 @@ again:
                            }
                            Warning("ProcessMessage", "file %s cannot be saved with this extension", fi.fFilename);
                         }
+                        for (int i=1;gSaveAsTypes[i];i+=2) {
+                           TString ftype = gSaveAsTypes[i];
+                           ftype.ReplaceAll("*.", ".");
+                           if (fn.EndsWith(ftype.Data())) {
+                              typeidx = i-1;
+                              break;
+                           }
+                        }
                      }
                      break;
                   case kFileSaveAsRoot:
@@ -962,7 +996,7 @@ again:
                         //   m->Update();
                         TColorWheel *wheel = new TColorWheel();
                         wheel->Draw();
-                        
+
                         //tp: with Cocoa, window is visible (and repainted)
                         //before wheel->Draw() was called and you can see "empty"
                         //canvas.
@@ -1294,8 +1328,7 @@ void TRootCanvas::FitCanvas()
    }
 }
 
-
- //______________________________________________________________________________
+//______________________________________________________________________________
 void TRootCanvas::PrintCanvas()
 {
    // Print the canvas.
@@ -1434,38 +1467,65 @@ void TRootCanvas::ShowEditor(Bool_t show)
    UInt_t h = GetHeight();
    UInt_t s = fHorizontal1->GetHeight();
 
-   if (show) {
-      if (!fEditor) CreateEditor();
-      TVirtualPadEditor* gged = TVirtualPadEditor::GetPadEditor(kFALSE);
-      if(gged && gged->GetCanvas() == fCanvas){
-         gged->Hide();
-      }
-      if (!fViewMenu->IsEntryChecked(kViewToolbar) || fToolDock->IsUndocked()) {
-         ShowFrame(fHorizontal1);
-         h = h + s;
-      }
-      fMainFrame->ShowFrame(fEditorFrame);
-      fEditor->Show();
-      fViewMenu->CheckEntry(kViewEditor);
-      w = w + e;
-   } else {
-      if (!fViewMenu->IsEntryChecked(kViewToolbar) || fToolDock->IsUndocked()) {
-         HideFrame(fHorizontal1);
-         h = h - s;
-      }
-      if (fEditor) fEditor->Hide();
-      fMainFrame->HideFrame(fEditorFrame);
-      fViewMenu->UnCheckEntry(kViewEditor);
-      w = w - e;
-   }
-   Resize(w, h);
    if (fParent && fParent != fClient->GetDefaultRoot()) {
-      // if the canvas is embedded (e.g. in the browser), then the layout of
-      // the main frame has to be re-applied when showing/hiding the editor
       TGMainFrame *main = (TGMainFrame *)fParent->GetMainFrame();
-      if (main) main->Layout();
+      fMainFrame->HideFrame(fEditorFrame);
+      if (main && main->InheritsFrom("TRootBrowser")) {
+         TRootBrowser *browser = (TRootBrowser *)main;
+         if (!fEmbedded)
+            browser->GetTabRight()->Connect("Selected(Int_t)", "TRootCanvas",
+                                            this, "Activated(Int_t)");
+         fEmbedded = kTRUE;
+         if (show && (!fEditor || !((TGedEditor *)fEditor)->IsMapped())) {
+            if (!browser->GetTabLeft()->GetTabTab("Pad Editor")) {
+               browser->StartEmbedding(TRootBrowser::kLeft);
+               if (!fEditor)
+                  fEditor = TVirtualPadEditor::GetPadEditor(kTRUE);
+               else {
+                  ((TGedEditor *)fEditor)->ReparentWindow(fClient->GetRoot());
+                  ((TGedEditor *)fEditor)->MapWindow();
+               }
+               browser->StopEmbedding("Pad Editor");
+               fEditor->SetGlobal(kFALSE);
+               gROOT->GetListOfCleanups()->Remove((TGedEditor *)fEditor);
+               if (fEditor) {
+                  ((TGedEditor *)fEditor)->SetCanvas(fCanvas);
+                  ((TGedEditor *)fEditor)->SetModel(fCanvas, fCanvas, kButton1Down);
+               }
+            }
+            else
+               fEditor = TVirtualPadEditor::GetPadEditor(kFALSE);
+         }
+         if (show) browser->GetTabLeft()->SetTab("Pad Editor");
+      }
+   }
+   else {
+      if (show) {
+         if (!fEditor) CreateEditor();
+         TVirtualPadEditor* gged = TVirtualPadEditor::GetPadEditor(kFALSE);
+         if(gged && gged->GetCanvas() == fCanvas){
+            gged->Hide();
+         }
+         if (!fViewMenu->IsEntryChecked(kViewToolbar) || fToolDock->IsUndocked()) {
+            ShowFrame(fHorizontal1);
+            h = h + s;
+         }
+         fMainFrame->ShowFrame(fEditorFrame);
+         fEditor->Show();
+         fViewMenu->CheckEntry(kViewEditor);
+         w = w + e;
+      } else {
+         if (!fViewMenu->IsEntryChecked(kViewToolbar) || fToolDock->IsUndocked()) {
+            HideFrame(fHorizontal1);
+            h = h - s;
+         }
+         if (fEditor) fEditor->Hide();
+         fMainFrame->HideFrame(fEditorFrame);
+         fViewMenu->UnCheckEntry(kViewEditor);
+         w = w - e;
+      }
+      Resize(w, h);
    }
-
    if (savedPad) gPad = savedPad;
 }
 
@@ -1734,6 +1794,9 @@ Bool_t TRootCanvas::HandleContainerKey(Event_t *event)
 {
    // Handle keyboard events in the canvas container.
 
+   static EGEventType previous_event = kOtherEvent;
+   static UInt_t previous_keysym = 0;
+
    if (event->fType == kGKeyPress) {
       fButton = event->fCode;
       UInt_t keysym;
@@ -1747,13 +1810,82 @@ Bool_t TRootCanvas::HandleContainerKey(Event_t *event)
          gPad->Modified();
          return kTRUE;
       }
-
       if (str[0] == 3)   // ctrl-c sets the interrupt flag
          gROOT->SetInterrupt();
-      fCanvas->HandleInput(kKeyPress, str[0], keysym);
-   } else if (event->fType == kKeyRelease)
-      fButton = 0;
 
+      // handle arrow keys
+      if (keysym > 0x1011 && keysym < 0x1016) {
+         Window_t dum1, dum2, wid;
+         UInt_t mask = 0;
+         Int_t mx, my, tx, ty;
+         wid = gVirtualX->GetDefaultRootWindow();
+         gVirtualX->QueryPointer(wid, dum1, dum2, mx, my, mx, my, mask);
+         gVirtualX->TranslateCoordinates(gClient->GetDefaultRoot()->GetId(),
+                                         fCanvasContainer->GetId(),
+                                         mx, my, tx, ty, dum1);
+         fCanvas->HandleInput(kArrowKeyPress, tx, ty);
+         // handle case where we got consecutive same keypressed events coming
+         // from auto-repeat on Windows (as it fires only successive keydown events)
+         if ((previous_keysym == keysym) && (previous_event == kGKeyPress)) {
+            switch (keysym) {
+               case 0x1012: // left
+                  gVirtualX->Warp(--mx, my, wid); --tx;
+                  break;
+               case 0x1013: // up
+                  gVirtualX->Warp(mx, --my, wid); --ty;
+                  break;
+               case 0x1014: // right
+                  gVirtualX->Warp(++mx, my, wid); ++tx;
+                  break;
+               case 0x1015: // down
+                  gVirtualX->Warp(mx, ++my, wid); ++ty;
+                  break;
+               default:
+                  break;
+            }
+            fCanvas->HandleInput(kArrowKeyRelease, tx, ty);
+         }
+         previous_keysym = keysym;
+      }
+      else {
+         fCanvas->HandleInput(kKeyPress, str[0], keysym);
+      }
+   } else if (event->fType == kKeyRelease) {
+      UInt_t keysym;
+      char str[2];
+      gVirtualX->LookupString(event, str, sizeof(str), keysym);
+
+      if (keysym > 0x1011 && keysym < 0x1016) {
+         Window_t dum1, dum2, wid;
+         UInt_t mask = 0;
+         Int_t mx, my, tx, ty;
+         wid = gVirtualX->GetDefaultRootWindow();
+         gVirtualX->QueryPointer(wid, dum1, dum2, mx, my, mx, my, mask);
+         switch (keysym) {
+            case 0x1012: // left
+               gVirtualX->Warp(--mx, my, wid);
+               break;
+            case 0x1013: // up
+               gVirtualX->Warp(mx, --my, wid);
+               break;
+            case 0x1014: // right
+               gVirtualX->Warp(++mx, my, wid);
+               break;
+            case 0x1015: // down
+               gVirtualX->Warp(mx, ++my, wid);
+               break;
+            default:
+               break;
+         }
+         gVirtualX->TranslateCoordinates(gClient->GetDefaultRoot()->GetId(),
+                                         fCanvasContainer->GetId(),
+                                         mx, my, tx, ty, dum1);
+         fCanvas->HandleInput(kArrowKeyRelease, tx, ty);
+         previous_keysym = keysym;
+      }
+      fButton = 0;
+   }
+   previous_event = event->fType;
    return kTRUE;
 }
 
@@ -1907,6 +2039,28 @@ Bool_t TRootCanvas::HandleDNDLeave()
    return kTRUE;
 }
 
+//______________________________________________________________________________
+void TRootCanvas::Activated(Int_t id)
+{
+   // Slot handling tab switching in the browser, to properly set the canvas 
+   // and the model to the editor.
+
+   if (fEmbedded) {
+      TGTab *sender = (TGTab *)gTQSender;
+      if (sender) {
+         TGCompositeFrame *cont = sender->GetTabContainer(id);
+         if (cont == fParent) {
+            if (!fEditor)
+               fEditor = TVirtualPadEditor::GetPadEditor(kFALSE);
+            if (fEditor && ((TGedEditor *)fEditor)->IsMapped()) {
+               ((TGedEditor *)fEditor)->SetCanvas(fCanvas);
+               ((TGedEditor *)fEditor)->SetModel(fCanvas, fCanvas, kButton1Down);
+            }
+         }
+      }
+   }
+}
+
 //______________________________________________________________________________
 void TRootContainer::SavePrimitive(ostream &out, Option_t * /*= ""*/)
 {
