@@ -126,7 +126,7 @@ TGraphErrors::TGraphErrors(Int_t n, const Double_t *x, const Double_t *y, const
 
 //______________________________________________________________________________
 TGraphErrors::TGraphErrors(const TVectorF &vx, const TVectorF &vy, const TVectorF &vex, const TVectorF &vey)
-   : TGraph()
+   : TGraph(TMath::Min(vx.GetNrows(), vy.GetNrows()), vx.GetMatrixArray(), vy.GetMatrixArray() )
 {
    // constructor with four vectors of floats in input
    // A grapherrors is built with the X coordinates taken from vx and Y coord from vy
@@ -134,16 +134,10 @@ TGraphErrors::TGraphErrors(const TVectorF &vx, const TVectorF &vy, const TVector
    // The number of points in the graph is the minimum of number of points
    // in vx and vy.
 
-   fNpoints = TMath::Min(vx.GetNrows(), vy.GetNrows());
-   if (!TGraph::CtorAllocate()) return;
    if (!CtorAllocate()) return;
-   Int_t ivxlow  = vx.GetLwb();
-   Int_t ivylow  = vy.GetLwb();
    Int_t ivexlow = vex.GetLwb();
    Int_t iveylow = vey.GetLwb();
    for (Int_t i = 0; i < fNpoints; i++) {
-      fX[i]   = vx(i + ivxlow);
-      fY[i]   = vy(i + ivylow);
       fEX[i]  = vex(i + ivexlow);
       fEY[i]  = vey(i + iveylow);
    }
@@ -152,7 +146,7 @@ TGraphErrors::TGraphErrors(const TVectorF &vx, const TVectorF &vy, const TVector
 
 //______________________________________________________________________________
 TGraphErrors::TGraphErrors(const TVectorD  &vx, const TVectorD  &vy, const TVectorD  &vex, const TVectorD  &vey)
-   : TGraph()
+   : TGraph(TMath::Min(vx.GetNrows(), vy.GetNrows()), vx.GetMatrixArray(), vy.GetMatrixArray() )
 {
    // constructor with four vectors of doubles in input
    // A grapherrors is built with the X coordinates taken from vx and Y coord from vy
@@ -160,16 +154,10 @@ TGraphErrors::TGraphErrors(const TVectorD  &vx, const TVectorD  &vy, const TVect
    // The number of points in the graph is the minimum of number of points
    // in vx and vy.
 
-   fNpoints = TMath::Min(vx.GetNrows(), vy.GetNrows());
-   if (!TGraph::CtorAllocate()) return;
    if (!CtorAllocate()) return;
-   Int_t ivxlow  = vx.GetLwb();
-   Int_t ivylow  = vy.GetLwb();
    Int_t ivexlow = vex.GetLwb();
    Int_t iveylow = vey.GetLwb();
    for (Int_t i = 0; i < fNpoints; i++) {
-      fX[i]   = vx(i + ivxlow);
-      fY[i]   = vy(i + ivylow);
       fEX[i]  = vex(i + ivexlow);
       fEY[i]  = vey(i + iveylow);
    }
@@ -235,11 +223,13 @@ TGraphErrors::TGraphErrors(const char *filename, const char *format, Option_t *o
    //  format = "%lg %lg"         read only 2 first columns into X,Y
    //  format = "%lg %lg %lg"     read only 3 first columns into X,Y and EY
    //  format = "%lg %lg %lg %lg" read only 4 first columns into X,Y,EX,EY.
+   //
    // For files separated by a specific delimiter different from ' ' and '\t' (e.g. ';' in csv files)
    // you can avoid using %*s to bypass this delimiter by explicitly specify the "option" argument,
    // e.g. option=" \t,;" for columns of figures separated by any of these characters (' ', '\t', ',', ';') 
    // used once (e.g. "1;1") or in a combined way (" 1;,;;  1"). 
    // Note in that case, the instanciation is about 2 times slower.
+   // In case a delimiter is specified, the format "%lg %lg %lg" will read X,Y,EX.
 
    if (!CtorAllocate()) return;
    Double_t x, y, ex, ey;
@@ -323,10 +313,10 @@ TGraphErrors::TGraphErrors(const char *filename, const char *format, Option_t *o
 
       // Looping
       while (std::getline(infile, line, '\n')) {
-         if (line[line.size() - 1] == char(13)) {  // removing DOS CR character 
-            line.erase(line.end() - 1, line.end()) ;
-         }
          if (line != "") {
+            if (line[line.size() - 1] == char(13)) {  // removing DOS CR character 
+               line.erase(line.end() - 1, line.end()) ;
+            }
             token = strtok(const_cast<char*>(line.c_str()), option) ;
             while (token != NULL && value_idx < ntokensToBeSaved) {
                if (isTokenToBeSaved[token_idx]) {
@@ -535,6 +525,30 @@ Bool_t TGraphErrors::CtorAllocate()
    return kTRUE;
 }
 
+//______________________________________________________________________________
+Bool_t TGraphErrors::DoMerge(const TGraph *g)
+{
+   //  protected function to perform the merge operation of a graph with errors
+
+   if (g->GetN() == 0) return kFALSE; 
+
+   Double_t * ex = g->GetEX();
+   Double_t * ey = g->GetEY();
+   if (ex == 0 || ey == 0 ) { 
+      if (g->IsA() != TGraph::Class() ) 
+         Warning("DoMerge","Merging a %s is not compatible with a TGraphErrors - errors will be ignored",g->IsA()->GetName());
+      return TGraph::DoMerge(g); 
+   }
+   for (Int_t i = 0 ; i < g->GetN(); i++) {
+      Int_t ipoint = GetN(); 
+      Double_t x = g->GetX()[i]; 
+      Double_t y = g->GetY()[i]; 
+      SetPoint(ipoint, x, y);
+      SetPointError( ipoint, ex[i], ey[i] ); 
+   }
+   return kTRUE;
+}
+
 
 //______________________________________________________________________________
 void TGraphErrors::FillZero(Int_t begin, Int_t end, Bool_t from_ctor)
