@@ -60,6 +60,9 @@ public:
    template <typename T>
    static Double_t GetBinError(T* p, Int_t bin);
 
+   template <typename T>
+   static void SetBinEntries(T* p, Int_t bin, Double_t w);
+
    template <typename T>
    static void SetErrorOption(T* p, Option_t * opt);
 };
@@ -187,7 +190,7 @@ Long64_t TProfileHelper::Merge(T* p, TCollection *li) {
    Bool_t initialLimitsFound = kFALSE;
    Bool_t allSameLimits = kTRUE;
    Bool_t allHaveLimits = kTRUE;
-   Bool_t firstNonEmptyHist = kTRUE;
+//   Bool_t firstNonEmptyHist = kTRUE;
 
    TIter next(&inlist);
    T* h = p;
@@ -195,7 +198,7 @@ Long64_t TProfileHelper::Merge(T* p, TCollection *li) {
    do {
 
       // skip empty histograms 
-      if (h->fTsumw == 0 && h->GetEntries() == 0) continue;
+      // if (h->fTsumw == 0 && h->GetEntries() == 0) continue;
 
       Bool_t hasLimits = h->GetXaxis()->GetXmin() < h->GetXaxis()->GetXmax();
       allHaveLimits = allHaveLimits && hasLimits;
@@ -203,6 +206,7 @@ Long64_t TProfileHelper::Merge(T* p, TCollection *li) {
       if (hasLimits) {
          h->BufferEmpty();
 
+#ifdef LATER
          // this is done in case the first histograms are empty and 
          // the histogram have different limits
          if (firstNonEmptyHist ) { 
@@ -217,6 +221,7 @@ Long64_t TProfileHelper::Merge(T* p, TCollection *li) {
             }
             firstNonEmptyHist = kFALSE;     
          }
+#endif
 
          // this is executed the first time an histogram with limits is found
          // to set some initial values on the new axis
@@ -704,8 +709,22 @@ Double_t TProfileHelper::GetBinError(T* p, Int_t bin)
 
    // default case : fErrorMode = kERRORMEAN 
    // return standard error on the mean of y 
+   //if (neff == 0) std::cerr << "NEFF = 0 for bin " << bin << "   " << eprim << "  " << neff << "  " << std::endl;
    return eprim/TMath::Sqrt(neff);
 
 }
 
+
+template <typename T>
+void TProfileHelper::SetBinEntries(T* p, Int_t bin, Double_t w) { 
+//    Set the number of entries in bin for the profile 
+//    In case the profile stores the sum of weight squares - set the sum of weight square to the number entries  
+//    (i.e. assume the entries have been filled all with a weight == 1 )   
+
+   if (bin < 0 || bin >= p->fNcells) return;
+   p->fBinEntries.fArray[bin] = w;
+   if (p->fBinSumw2.fN) p->fBinSumw2.fArray[bin] = w;
+
+}
+
 #endif
