@@ -765,6 +765,10 @@ TObject *TKey::ReadObj()
    // Create an instance of this class
 
    char *pobj = (char*)cl->New();
+   if (!pobj) {
+      Error("ReadObj", "Cannot create new object of class %s", fClassName.Data());
+      return 0;
+   }
    Int_t baseOffset = cl->GetBaseClassOffset(TObject::Class());
    if (baseOffset==-1) {
       // cl does not inherit from TObject.
@@ -774,10 +778,6 @@ TObject *TKey::ReadObj()
             fClassName.Data());
    }
    tobj = (TObject*)(pobj+baseOffset);
-   if (!pobj) {
-      Error("ReadObj", "Cannot create new object of class %s", fClassName.Data());
-      return 0;
-   }
    if (kvers > 1)
       fBufferRef->MapObject(pobj,cl);  //register obj in map to handle self reference
 
@@ -801,7 +801,9 @@ TObject *TKey::ReadObj()
          delete [] fBuffer;
       } else {
          delete [] fBuffer;
-         delete pobj;
+         // Even-though we have a TObject, if the class is emulated the virtual
+         // table may not be 'right', so let's go via the TClass.
+         cl->Destructor(pobj);
          pobj = 0;
          tobj = 0;
          goto CLEAR;
@@ -892,6 +894,10 @@ TObject *TKey::ReadObjWithBuffer(char *bufferRead)
    // Create an instance of this class
 
    char *pobj = (char*)cl->New();
+   if (!pobj) {
+      Error("ReadObjWithBuffer", "Cannot create new object of class %s", fClassName.Data());
+      return 0;
+   }
    Int_t baseOffset = cl->GetBaseClassOffset(TObject::Class());
    if (baseOffset==-1) {
       // cl does not inherit from TObject.
@@ -901,10 +907,7 @@ TObject *TKey::ReadObjWithBuffer(char *bufferRead)
             fClassName.Data());
    }
    tobj = (TObject*)(pobj+baseOffset);
-   if (!pobj) {
-      Error("ReadObjWithBuffer", "Cannot create new object of class %s", fClassName.Data());
-      return 0;
-   }
+
    if (kvers > 1)
       fBufferRef->MapObject(pobj,cl);  //register obj in map to handle self reference
 
@@ -926,7 +929,9 @@ TObject *TKey::ReadObjWithBuffer(char *bufferRead)
       if (nout) {
          tobj->Streamer(*fBufferRef); //does not work with example 2 above
       } else {
-         delete pobj;
+         // Even-though we have a TObject, if the class is emulated the virtual
+         // table may not be 'right', so let's go via the TClass.
+         cl->Destructor(pobj);
          pobj = 0;
          tobj = 0;
          goto CLEAR;
