@@ -29,6 +29,27 @@ namespace ROOT {
 
 namespace Math { 
 
+/**
+   FunctorImpl is a base class for the functor 
+   handler implementation class. 
+   It defines the Copy operator used to clone the functor objects
+*/
+
+template<class IBaseFunc> 
+class FunctorImpl : public IBaseFunc { 
+
+public: 
+
+   typedef IBaseFunc BaseFunc; 
+
+
+   FunctorImpl() : IBaseFunc() { }
+
+   virtual ~FunctorImpl() {}
+
+   virtual FunctorImpl* Copy() const = 0; 
+
+};
 
 /** 
    Functor Handler class is responsible for wrapping any other functor and pointer to 
@@ -54,6 +75,7 @@ class FunctorHandler : public ParentFunctor::Impl {
    typedef typename ImplFunc::BaseFunc BaseFunc; 
    //typedef typename ParentFunctor::Dim Dim; 
 
+
 public: 
 
    // constructor for 1d functions 
@@ -66,11 +88,19 @@ public:
       fFunc(fun) 
    {}
 
-   // clone of the function handler (use copy-ctor) 
-   BaseFunc * Clone() const { 
+   virtual ~FunctorHandler() {}
+
+   // copy of the function handler (use copy-ctor)
+   ImplFunc * Copy() const { 
      return new FunctorHandler(*this); 
    }
 
+   // clone of the function handler (use copy-ctor) 
+   BaseFunc * Clone() const { 
+      return Copy(); 
+   }
+
+
    // constructor for multi-dimensional functions
    unsigned int NDim() const { 
       return fDim;
@@ -138,8 +168,13 @@ public:
       fGradFunc( gfun ) 
    {}
 
+   virtual ~FunctorGradHandler() {} 
+
    // clone of the function handler (use copy-ctor) 
-   BaseFunc * Clone() const { return new FunctorGradHandler(*this); }
+   ImplFunc * Copy() const { return new FunctorGradHandler(*this); }
+
+   // clone of the function handler (use copy-ctor) 
+   BaseFunc * Clone() const { return Copy(); }
 
    // constructor for multi-dimensional functions
    unsigned int NDim() const { 
@@ -200,8 +235,12 @@ public:
    MemFunHandler(unsigned int dim, const PointerToObj& pObj, PointerToMemFn pMemFn) 
       : fDim(dim), fObj(pObj), fMemFn(pMemFn)
    {}
-        
+
+   virtual ~MemFunHandler() {}
    
+   // clone of the function handler (use copy-ctor) 
+   ImplFunc * Copy() const { return new MemFunHandler(*this); }
+
    // clone of the function handler (use copy-ctor) 
    BaseFunc * Clone() const { return new MemFunHandler(*this); }
 
@@ -265,10 +304,14 @@ public:
         fMemFn(pMemFn), 
         fGradMemFn(pGradMemFn)
    {}
-        
+       
+   virtual ~MemGradFunHandler() {}
+
+   // clone of the function handler (use copy-ctor) 
+   ImplFunc * Copy() const { return new MemGradFunHandler(*this); }
    
    // clone of the function handler (use copy-ctor) 
-     BaseFunc * Clone() const { return new MemGradFunHandler(*this); }
+   BaseFunc * Clone() const { return new MemGradFunHandler(*this); }
 
    // constructor for multi-dimensional functions
    unsigned int NDim() const { 
@@ -300,25 +343,31 @@ private :
 };
   
 
-#if defined(__MAKECINT__) || defined(G__DICTIONARY) 
+//****************************
+// LM 7/2/2014:  no needed this : make template ctor of Functor1D and GradFunctor1D not 
+// available to CINT s
+//***************************************
+//#if defined(__MAKECINT__) || defined(G__DICTIONARY) 
 // needed since CINT initialize it with TRootIOCtor
 //class TRootIOCtor; 
-template<class ParentFunctor> 
-class FunctorHandler<ParentFunctor,TRootIOCtor *> : public ParentFunctor::Impl 
-{
-public:
-   typedef typename ParentFunctor::Impl ImplFunc; 
-   typedef typename ImplFunc::BaseFunc BaseFunc; 
 
-   FunctorHandler(TRootIOCtor  *) {}
-   // function required by interface
-   double DoEval (double ) const  { return 0; } 
-   double DoDerivative (double ) const  { return 0; } 
-   BaseFunc  * Clone() const {  return 0;  } 
+// template<class ParentFunctor> 
+// class FunctorHandler<ParentFunctor,TRootIOCtor *> : public ParentFunctor::Impl 
+// {
+// public:
+//    typedef typename ParentFunctor::Impl ImplFunc; 
+//    typedef typename ImplFunc::BaseFunc BaseFunc; 
 
-}; 
-#endif   
+//    FunctorHandler(TRootIOCtor  *) {}
+//    // function required by interface
+//    virtual ~FunctorHandler() {}
+//    double DoEval (double ) const  { return 0; } 
+//    double DoDerivative (double ) const  { return 0; } 
+//    ImplFunc  * Copy() const {  return 0;  } 
+//    BaseFunc  * Clone() const {  return 0;  } 
 
+// }; 
+// #endif   
 
 
 //_______________________________________________________________________________________________
@@ -342,7 +391,7 @@ class Functor : public IBaseFunctionMultiDim  {
 
 public: 
 
-   typedef IBaseFunctionMultiDim Impl;   
+   typedef FunctorImpl<IBaseFunctionMultiDim> Impl;   
    typedef IBaseFunctionMultiDim::BaseFunc ImplBase;   
 
    /** 
@@ -382,19 +431,17 @@ public:
    */ 
    virtual ~Functor ()  {}  
 
-#ifndef __CINT__
    /** 
       Copy constructor for functor based on ROOT::Math::IMultiGenFunction
    */ 
    Functor(const Functor & rhs) : 
-      Impl()  
+      ImplBase()  
    {
       if (rhs.fImpl.get() != 0) 
-         fImpl = std::auto_ptr<Impl>( (rhs.fImpl)->Clone() ); 
+         fImpl = std::auto_ptr<Impl>( (rhs.fImpl)->Copy() ); 
    } 
    // need a specialization in order to call base classes and use  clone
 
-#endif
 
    /** 
       Assignment operator
@@ -449,7 +496,7 @@ class Functor1D : public IBaseFunctionOneDim  {
 
 public: 
 
-   typedef IBaseFunctionOneDim          Impl;   
+   typedef FunctorImpl<IBaseFunctionOneDim>          Impl;   
    typedef IBaseFunctionOneDim::BaseFunc ImplBase; 
 
    /** 
@@ -457,6 +504,17 @@ public:
    */ 
    Functor1D ()  : fImpl(0) {}  
 
+#ifndef __CINT__
+   /**
+      construct from a callable object with the right signature 
+      implementing operator() (double x)
+    */
+   template <typename Func> 
+   Functor1D(const Func & f) : 
+      fImpl(new FunctorHandler<Functor1D,Func>(f) )
+   {}
+#endif
+
 
    /** 
        construct from a pointer to member function (1D type)
@@ -467,39 +525,28 @@ public:
    {}
 
 
-   /**
-      construct from a callable object with the right signature 
-      implementing operator() (double x)
-    */
-   template <typename Func> 
-   Functor1D(const Func & f) : 
-      fImpl(new FunctorHandler<Functor1D,Func>(f) )
-   {}
-
-
    //implement for interpreted CINT functions
 #if defined(__CINT__) || defined(G__DICTIONARY) || defined(MAKE_CINT_FUNCTOR)
    Functor1D(void * p, const char * className = 0, const char * methodName = 0);
-#endif 
+
+#endif
 
    /** 
       Destructor (no operations)
    */ 
    virtual ~Functor1D ()  {}  
 
-#ifndef __CINT__
 
    /** 
       Copy constructor for Functor based on ROOT::Math::IGenFunction
    */ 
    Functor1D(const Functor1D & rhs) : 
-      // strange that this is required eventhough Impl is an abstract class
-      Impl()
+      // strange that this is required eventhough ImplBase is an abstract class
+      ImplBase()
    {
       if (rhs.fImpl.get() != 0) 
-         fImpl = std::auto_ptr<Impl>( (rhs.fImpl)->Clone() ); 
+         fImpl = std::auto_ptr<Impl>( (rhs.fImpl)->Copy() ); 
    } 
-#endif
 
 
    /** 
@@ -556,7 +603,7 @@ class GradFunctor : public IGradientFunctionMultiDim  {
 
 public: 
 
-   typedef IGradientFunctionMultiDim Impl;   
+   typedef FunctorImpl<IGradientFunctionMultiDim> Impl;   
    typedef IGradientFunctionMultiDim::BaseFunc ImplBase;   
    
 
@@ -604,19 +651,17 @@ public:
    */ 
    virtual ~GradFunctor ()  {}  
 
-#ifndef __CINT__
 
    /** 
       Copy constructor for functor based on ROOT::Math::IMultiGradFunction
    */ 
    GradFunctor(const GradFunctor & rhs) : 
-      ImplBase(),
-      Impl() 
+      ImplBase(), 
+      IGradientFunctionMultiDim()
    {
       if (rhs.fImpl.get() != 0) 
-         fImpl = std::auto_ptr<Impl>( dynamic_cast<Impl *>( (rhs.fImpl)->Clone()) ); 
+         fImpl = std::auto_ptr<Impl>( rhs.fImpl->Copy() ); 
    } 
-#endif
 
    /** 
       Assignment operator
@@ -679,7 +724,7 @@ class GradFunctor1D : public IGradientFunctionOneDim  {
 
 public: 
 
-   typedef IGradientFunctionOneDim  Impl; 
+   typedef FunctorImpl<IGradientFunctionOneDim>  Impl; 
    typedef IGradientFunctionOneDim::BaseFunc ImplBase; 
    
 
@@ -688,6 +733,8 @@ public:
    */ 
    GradFunctor1D ()  : fImpl(0) {}  
 
+
+#ifndef __CINT__
    /**
       construct from an object with the right signature 
       implementing both operator() (double x) and Derivative(double x)
@@ -696,6 +743,7 @@ public:
    GradFunctor1D(const Func & f) : 
       fImpl(new FunctorHandler<GradFunctor1D,Func>(f) )
    {}
+#endif
 
 
    /** 
@@ -709,6 +757,13 @@ public:
    {}
 
 
+
+   // eventually implement for interpreted CINT functions
+#if defined(__CINT__) || defined(G__DICTIONARY) || defined(MAKE_CINT_FUNCTOR)
+   GradFunctor1D(void * p1, const char * className, const char * methodName, const char * derivName);
+   GradFunctor1D(void * p1, void * p2);
+#endif
+
    /**
       construct from two 1D function objects
     */
@@ -717,31 +772,23 @@ public:
       fImpl(new FunctorGradHandler<GradFunctor1D,Func, GradFunc>(f, g) )
    {}
 
-   // eventually implement for interpreted CINT functions
-#if defined(__CINT__) || defined(G__DICTIONARY) || defined(MAKE_CINT_FUNCTOR)
-   GradFunctor1D(void * p1, const char * className, const char * methodName, const char * derivName);
-   GradFunctor1D(void * p1, void * p2);
-#endif 
-
    /** 
       Destructor (no operations)
    */ 
    virtual ~GradFunctor1D ()  {}  
 
-#ifndef __CINT__
 
    /** 
       Copy constructor for Functor based on ROOT::Math::IGradFunction
    */ 
    GradFunctor1D(const GradFunctor1D & rhs) : 
       // strange that this is required eventhough Impl is an abstract class
-      ImplBase(),          
-      Impl()  
+      ImplBase(), 
+      IGradientFunctionOneDim()          
    {
       if (rhs.fImpl.get() != 0) 
-         fImpl = std::auto_ptr<Impl>( dynamic_cast<Impl *>( (rhs.fImpl)->Clone() ) ); 
+         fImpl = std::auto_ptr<Impl>( rhs.fImpl->Copy()  ); 
    } 
-#endif
 
 
    /** 
