@@ -159,7 +159,7 @@ MnUserCovariance MnUserTransformation::Int2extCovariance(const MnAlgebraicVector
 }
 
 double MnUserTransformation::Ext2int(unsigned int i, double val) const {
-   // return the external value for parameter i with value val
+   // return the internal value for parameter i with external value val
    
    if(fParameters[i].HasLimits()) {
       if(fParameters[i].HasUpperLimit() && fParameters[i].HasLowerLimit())
@@ -351,6 +351,13 @@ void MnUserTransformation::RemoveLimits(unsigned int n) {
    fParameters[n].RemoveLimits();
 }
 
+void MnUserTransformation::SetName(unsigned int n, const std::string & name) {
+   // set name for parameter n (external index)
+   assert(n < fParameters.size()); 
+   fParameters[n].SetName(name);
+}
+
+
 double MnUserTransformation::Value(unsigned int n) const {
    // get value for parameter n (external index)
    assert(n < fParameters.size()); 
