@@ -39,6 +39,9 @@
 #include "TObjString.h"
 #include "TPluginManager.h"
 #include "TDataSetManager.h"
+#include "TDataSetManagerFile.h"
+#include "TParameter.h"
+#include "TPRegexp.h"
 #include "TProofQueryResult.h"
 #include "TProofServ.h"
 #include "TQueryResultManager.h"
@@ -77,6 +80,8 @@ TProofLite::TProofLite(const char *url, const char *conffile, const char *confdi
    fQueryLock = 0;
    fQMgr = 0;
    fDataSetManager = 0;
+   fDataSetStgRepo = 0;
+   fReInvalid = new TPMERegexp("[^A-Za-z0-9._-]");
    InitMembers();
 
    // This may be needed during init
@@ -383,6 +388,10 @@ TProofLite::~TProofLite()
       fQueryLock->Unlock();
    }
 
+   SafeDelete(fReInvalid);
+   SafeDelete(fDataSetManager);
+   SafeDelete(fDataSetStgRepo);
+
    // Cleanup the socket
    SafeDelete(fServSock);
    gSystem->Unlink(fSockPath);
@@ -784,7 +793,7 @@ Int_t TProofLite::SetProofServEnv(const char *ord)
       TNamed *env = 0;
       while ((env = (TNamed *)nxenv())) {
          TString senv(env->GetTitle());
-         ResolveKeywords(senv, logfile.Data());
+         ResolveKeywords(senv, ord, logfile.Data());
          fprintf(fenv, "export %s=%s\n", env->GetName(), senv.Data());
          if (namelist.Length() > 0)
             namelist += ',';
@@ -801,10 +810,11 @@ Int_t TProofLite::SetProofServEnv(const char *ord)
 }
 
 //__________________________________________________________________________
-void TProofLite::ResolveKeywords(TString &s, const char *logfile)
+void TProofLite::ResolveKeywords(TString &s, const char *ord,
+   const char *logfile)
 {
    // Resolve some keywords in 's'
-   //    <logfileroot>, <user>, <rootsys>
+   //    <logfilewrk>, <user>, <rootsys>, <cpupin>
 
    if (!logfile) return;
 
@@ -824,6 +834,59 @@ void TProofLite::ResolveKeywords(TString &s, const char *logfile)
    if (gSystem->Getenv("ROOTSYS") && s.Contains("<rootsys>")) {
       s.ReplaceAll("<rootsys>", gSystem->Getenv("ROOTSYS"));
    }
+
+   // cpupin: pin to this CPU num (from 0 to ncpus-1)
+   if (s.Contains("<cpupin>")) {
+      TString o = ord;
+      Int_t n = o.Index('.');
+      if (n != kNPOS) {
+
+         o.Remove(0, n+1);
+         n = o.Atoi();  // n is ord
+
+         TString cpuPinList;
+         {
+            const TList *envVars = GetEnvVars();
+            TNamed *var;
+            if (envVars) {
+               var = dynamic_cast<TNamed *>(envVars->FindObject("PROOF_SLAVE_CPUPIN_ORDER"));
+               if (var) cpuPinList = var->GetTitle();
+            }
+         }
+
+         UInt_t nCpus = 1;
+         {
+            SysInfo_t si;
+            if (gSystem->GetSysInfo(&si) == 0 && (si.fCpus > 0))
+               nCpus = si.fCpus;
+            else nCpus = 1;  // fallback
+         }
+
+         if (cpuPinList.IsNull() || (cpuPinList == "*")) {
+            // Use processors in order
+            n = n % nCpus;
+         }
+         else {
+            // Use processors in user's order
+            // n is now the ordinal, converting to idx
+            n = n % (cpuPinList.CountChar('+')+1);
+            TString tok;
+            Ssiz_t from = 0;
+            for (Int_t i=0; cpuPinList.Tokenize(tok, from, "\\+"); i++) {
+               if (i == n) {
+                  n = (tok.Atoi() % nCpus);
+                  break;
+               }
+            }
+         }
+
+         o.Form("%d", n);
+      }
+      else {
+         o = "0";  // should not happen
+      }
+      s.ReplaceAll("<cpupin>", o);
+   }
 }
 
 //______________________________________________________________________________
@@ -1321,6 +1384,14 @@ Long64_t TProofLite::Process(TDSet *dset, const char *selector, Option_t *option
    // Finalise output file settings (opt is ignored in here)
    if (HandleOutputOptions(opt, outfile, 1) != 0) return -1;
 
+   // Retrieve status from the output list
+   if (rv >= 0) {
+      TParameter<Long64_t> *sst =
+        (TParameter<Long64_t> *) fOutputList.FindObject("PROOF_SelectorStatus");
+      if (sst) rv = sst->GetVal();
+   }
+
+
    // Done
    return rv;
 }
@@ -1431,6 +1502,26 @@ Int_t TProofLite::InitDataSetManager()
             fDataSetManager->TestBit(TDataSetManager::kIsSandbox));
    }
 
+   // Dataset manager for staging requests
+   TString dsReqCfg = gEnv->GetValue("Proof.DataSetStagingRequests", "");
+   if (!dsReqCfg.IsNull()) {
+      TPMERegexp reReqDir("(^| )(dir:)?([^ ]+)( |$)");
+
+      if (reReqDir.Match(dsReqCfg) == 5) {
+         TString dsDirFmt;
+         dsDirFmt.Form("dir:%s perms:open", reReqDir[3].Data());
+         fDataSetStgRepo = new TDataSetManagerFile("_stage_", "_stage_", dsDirFmt);
+         if (fDataSetStgRepo && fDataSetStgRepo->TestBit(TObject::kInvalidObject)) {
+            Warning("InitDataSetManager", "failed init of dataset staging requests repository");
+            SafeDelete(fDataSetStgRepo);
+         }
+      } else {
+         Warning("InitDataSetManager", "specify, with [dir:]<path>, a valid path for staging requests");
+      }
+   } else if (gDebug > 0) {
+      Warning("InitDataSetManager", "no repository for staging requests available");
+   }
+
    // Done
    return (fDataSetManager ? 0 : -1);
 }
@@ -1738,7 +1829,7 @@ Int_t TProofLite::CleanupSandbox()
 {
    // Remove old sessions dirs keep at most 'Proof.MaxOldSessions' (default 10)
 
-   Int_t maxold = gEnv->GetValue("Proof.MaxOldSessions", 10);
+   Int_t maxold = gEnv->GetValue("Proof.MaxOldSessions", 1);
 
    if (maxold < 0) return 0;
 
@@ -2040,6 +2131,132 @@ Int_t TProofLite::RemoveDataSet(const char *uri, const char *)
    return 0;
 }
 
+//______________________________________________________________________________
+Bool_t TProofLite::RequestStagingDataSet(const char *dataset)
+{
+   // Allows users to request staging of a particular dataset. Requests are
+   // saved in a special dataset repository and must be honored by the endpoint.
+   // This is the special PROOF-Lite re-implementation of the TProof function
+   // and includes code originally implemented in TProofServ.
+
+   if (!dataset) {
+      Error("RequestStagingDataSet", "invalid dataset specified");
+      return kFALSE;
+   }
+
+   if (!fDataSetStgRepo) {
+      Error("RequestStagingDataSet", "no dataset staging request repository available");
+      return kFALSE;
+   }
+
+   TString dsUser, dsGroup, dsName, dsTree;
+
+   // Transform input URI in a valid dataset name
+   TString validUri = dataset;
+   while (fReInvalid->Substitute(validUri, "_")) {}
+
+   // Check if dataset exists beforehand: if it does, staging has already been requested
+   if (fDataSetStgRepo->ExistsDataSet(validUri.Data())) {
+      Warning("RequestStagingDataSet", "staging of %s already requested", dataset);
+      return kFALSE;
+   }
+
+   // Try to get dataset from current manager
+   TFileCollection *fc = fDataSetManager->GetDataSet(dataset);
+   if (!fc || (fc->GetNFiles() == 0)) {
+      Error("RequestStagingDataSet", "empty dataset or no dataset returned");
+      if (fc) delete fc;
+      return kFALSE;
+   }
+
+   // Reset all staged bits and remove unnecessary URLs (all but last)
+   TIter it(fc->GetList());
+   TFileInfo *fi;
+   while ((fi = dynamic_cast<TFileInfo *>(it.Next()))) {
+      fi->ResetBit(TFileInfo::kStaged);
+      Int_t nToErase = fi->GetNUrls() - 1;
+      for (Int_t i=0; i<nToErase; i++)
+         fi->RemoveUrlAt(0);
+   }
+
+   fc->Update();  // absolutely necessary
+
+   // Save request
+   fDataSetStgRepo->ParseUri(validUri, &dsGroup, &dsUser, &dsName);
+   if (fDataSetStgRepo->WriteDataSet(dsGroup, dsUser, dsName, fc) == 0) {
+      // Error, can't save dataset
+      Error("RequestStagingDataSet", "can't register staging request for %s", dataset);
+      delete fc;
+      return kFALSE;
+   }
+
+   Info("RequestStagingDataSet", "Staging request registered for %s", dataset);
+   delete fc;
+
+   return kTRUE;
+}
+
+//______________________________________________________________________________
+Bool_t TProofLite::CancelStagingDataSet(const char *dataset)
+{
+   // Cancels a dataset staging request. Returns kTRUE on success, kFALSE on
+   // failure. Dataset not found equals to a failure. PROOF-Lite
+   // re-implementation of the equivalent function in TProofServ.
+
+   if (!dataset) {
+      Error("CancelStagingDataSet", "invalid dataset specified");
+      return kFALSE;
+   }
+
+   if (!fDataSetStgRepo) {
+      Error("CancelStagingDataSet", "no dataset staging request repository available");
+      return kFALSE;
+   }
+
+   // Transform URI in a valid dataset name
+   TString validUri = dataset;
+   while (fReInvalid->Substitute(validUri, "_")) {}
+
+   if (!fDataSetStgRepo->RemoveDataSet(validUri.Data()))
+      return kFALSE;
+
+   return kTRUE;
+}
+
+//______________________________________________________________________________
+TFileCollection *TProofLite::GetStagingStatusDataSet(const char *dataset)
+{
+   // Obtains a TFileCollection showing the staging status of the specified
+   // dataset. A valid dataset manager and dataset staging requests repository
+   // must be present on the endpoint. PROOF-Lite version of the equivalent
+   // function from TProofServ.
+
+   if (!dataset) {
+      Error("GetStagingStatusDataSet", "invalid dataset specified");
+      return 0;
+   }
+
+   if (!fDataSetStgRepo) {
+      Error("GetStagingStatusDataSet", "no dataset staging request repository available");
+      return 0;
+   }
+
+   // Transform URI in a valid dataset name
+   TString validUri = dataset;
+   while (fReInvalid->Substitute(validUri, "_")) {}
+
+   // Get the list
+   TFileCollection *fc = fDataSetStgRepo->GetDataSet(validUri.Data());
+   if (!fc) {
+      // No such dataset (not an error)
+      Info("GetStagingStatusDataSet", "no pending staging request for %s", dataset);
+      return 0;
+   }
+
+   // Dataset found: return it (must be cleaned by caller)
+   return fc;
+}
+
 //______________________________________________________________________________
 Int_t TProofLite::VerifyDataSet(const char *uri, const char *optStr)
 {
