@@ -133,7 +133,7 @@ public:
 
    void FileOpenEvent(TFile *file, const char *filename, Double_t start);
    void FileReadEvent(TFile *file, Int_t len, Double_t start);
-   void FileUnzipEvent(TFile *file, Long64_t pos, Double_t start, Int_t complen, Int_t objlen);
+   void UnzipEvent(TObject *tree, Long64_t pos, Double_t start, Int_t complen, Int_t objlen);
    void RateEvent(Double_t proctime, Double_t deltatime,
                   Long64_t eventsprocessed, Long64_t bytesRead);
    void SetBytesRead(Long64_t num);
