@@ -94,8 +94,11 @@ Long64_t TProofPlayerLite::Process(TDSet *dset, TSelector *selector,
    }
 
    fCreateSelObj = kFALSE;
+   Long64_t rc = Process(dset, selector->ClassName(), option, nentries, first);
+   fCreateSelObj = kTRUE;
 
-   return Process(dset, selector->ClassName(), option, nentries, first);
+   // Done
+   return rc;
 }
 
 //______________________________________________________________________________
@@ -213,12 +216,22 @@ Long64_t TProofPlayerLite::Process(TDSet *dset, const char *selector_file,
    }
    // reset start, this is now managed by the packetizer
    first = 0;
-   // Try to have 100 messages about memory, unless a different number is given by the user
-   if (!fProof->GetParameter("PROOF_MemLogFreq")){
-      Long64_t memlogfreq = fPacketizer->GetTotalEntries()/(fProof->GetParallel()*100);
-      memlogfreq = (memlogfreq > 0) ? memlogfreq : 1;
-      fProof->SetParameter("PROOF_MemLogFreq", memlogfreq);
+
+   // Negative memlogfreq disable checks.
+   // If 0 is passed we try to have 100 messages about memory
+   // Otherwise we use the frequency passed.
+   Int_t mrc = -1;
+   Long64_t memlogfreq = -1, mlf;
+   if ((mrc = TProof::GetParameter(fProof->GetInputList(), "PROOF_MemLogFreq", mlf)) == 0) memlogfreq = mlf;
+   if (mrc != 0 && gSystem->Getenv("PROOF_MEMLOGFREQ")) {
+      TString clf(gSystem->Getenv("PROOF_MEMLOGFREQ"));
+      if (clf.IsDigit()) { memlogfreq = clf.Atoi(); mrc = 0; }
    }
+   if (memlogfreq == 0) {
+      memlogfreq = fPacketizer->GetTotalEntries()/(fProof->GetParallel()*100);
+      if (memlogfreq <= 0) memlogfreq = 1;
+   }
+   if (mrc == 0) fProof->SetParameter("PROOF_MemLogFreq", memlogfreq);
 
    // Add the unique query tag as TNamed object to the input list
    // so that it is available in TSelectors for monitoring
@@ -409,7 +422,7 @@ Long64_t TProofPlayerLite::Finalize(Bool_t force, Bool_t sync)
       fOutput->SetOwner();
       SafeDelete(fSelector);
       if (!fCreateSelObj) fSelector = 0;
-    }
+   }
 
    PDB(kGlobal,1) Info("Finalize","exit");
    return rv;
