@@ -50,6 +50,10 @@ RooHistFunc::RooHistFunc() :
   _unitNorm(kFALSE)
 {
   // Default constructor
+  TRACE_CREATE 
+
+  _histObsIter = _histObsList.createIterator() ;
+  _pdfObsIter = _depList.createIterator() ;
 }
 
 
@@ -71,8 +75,12 @@ RooHistFunc::RooHistFunc(const char *name, const char *title, const RooArgSet& v
   // RooHistFunc neither owns or clone 'dhist' and the user must ensure the input histogram exists
   // for the entire life span of this function.
 
+  _histObsList.addClone(vars) ;
   _depList.add(vars) ;
 
+  _histObsIter = _histObsList.createIterator() ;
+  _pdfObsIter = _depList.createIterator() ;
+
   // Verify that vars and dhist.get() have identical contents
   const RooArgSet* dvars = dhist.get() ;
   if (vars.getSize()!=dvars->getSize()) {
@@ -90,7 +98,53 @@ RooHistFunc::RooHistFunc(const char *name, const char *title, const RooArgSet& v
     }
   }
   delete iter ;
+  TRACE_CREATE 
+}
 
+
+
+//_____________________________________________________________________________
+RooHistFunc::RooHistFunc(const char *name, const char *title, const RooArgList& funcObs, const RooArgList& histObs, 
+  		       const RooDataHist& dhist, Int_t intOrder) :
+  RooAbsReal(name,title), 
+  _depList("depList","List of dependents",this),
+  _dataHist((RooDataHist*)&dhist), 
+  _codeReg(10),
+  _intOrder(intOrder),
+  _cdfBoundaries(kFALSE),
+  _totVolume(0),
+  _unitNorm(kFALSE)
+{
+  // Constructor from a RooDataHist. The variable listed in 'vars' control the dimensionality of the
+  // function. Any additional dimensions present in 'dhist' will be projected out. RooDataHist dimensions
+  // can be either real or discrete. See RooDataHist::RooDataHist for details on the binning.
+  // RooHistFunc neither owns or clone 'dhist' and the user must ensure the input histogram exists
+  // for the entire life span of this function.
+
+  _histObsList.addClone(histObs) ;
+  _depList.add(funcObs) ;
+
+  _histObsIter = _histObsList.createIterator() ;
+  _pdfObsIter = _depList.createIterator() ;
+
+  // Verify that vars and dhist.get() have identical contents
+  const RooArgSet* dvars = dhist.get() ;
+  if (histObs.getSize()!=dvars->getSize()) {
+    coutE(InputArguments) << "RooHistFunc::ctor(" << GetName() 
+			  << ") ERROR variable list and RooDataHist must contain the same variables." << endl ;
+    assert(0) ;
+  }
+  TIterator* iter = histObs.createIterator() ;
+  RooAbsArg* arg ;
+  while((arg=(RooAbsArg*)iter->Next())) {
+    if (!dvars->find(arg->GetName())) {
+      coutE(InputArguments) << "RooHistFunc::ctor(" << GetName() 
+			    << ") ERROR variable list and RooDataHist must contain the same variables." << endl ;
+      assert(0) ;
+    }
+  }
+  delete iter ;
+  TRACE_CREATE 
 }
 
 
@@ -107,10 +161,28 @@ RooHistFunc::RooHistFunc(const RooHistFunc& other, const char* name) :
   _unitNorm(other._unitNorm)
 {
   // Copy constructor
+  TRACE_CREATE 
+
+  _histObsList.addClone(other._histObsList) ;
+
+  _histObsIter = _histObsList.createIterator() ;
+  _pdfObsIter = _depList.createIterator() ;
 }
 
 
 
+//_____________________________________________________________________________
+RooHistFunc::~RooHistFunc() 
+{ 
+  TRACE_DESTROY 
+
+  delete _histObsIter ;
+  delete _pdfObsIter ;
+}
+
+
+
+
 //_____________________________________________________________________________
 Double_t RooHistFunc::evaluate() const
 {
@@ -118,7 +190,24 @@ Double_t RooHistFunc::evaluate() const
   // of the dependents, normalized by the histograms contents. Interpolation
   // is applied if the RooHistFunc is configured to do that
 
-  Double_t ret =  _dataHist->weight(_depList,_intOrder,kFALSE,_cdfBoundaries) ;  
+  // Transfer values from   
+  if (_depList.getSize()>0) {
+    _histObsIter->Reset() ;
+    _pdfObsIter->Reset() ;
+    RooAbsArg* harg, *parg ;
+    while((harg=(RooAbsArg*)_histObsIter->Next())) {
+      parg = (RooAbsArg*)_pdfObsIter->Next() ;
+      if (harg != parg) {
+	parg->syncCache() ;
+	harg->copyCache(parg,kTRUE) ;
+	if (!harg->inRange(0)) {
+	  return 0 ;
+	}
+      }
+    }
+  }
+
+  Double_t ret =  _dataHist->weight(_histObsList,_intOrder,kFALSE,_cdfBoundaries) ;  
   return ret ;
 }
 
@@ -259,7 +348,23 @@ Double_t RooHistFunc::analyticalIntegral(Int_t code, const char* /*rangeName*/)
   }
   delete iter ;
 
-  Double_t ret =  _dataHist->sum(intSet,_depList,kTRUE) ;
+  if (_depList.getSize()>0) {
+    _histObsIter->Reset() ;
+    _pdfObsIter->Reset() ;
+    RooAbsArg* harg, *parg ;
+    while((harg=(RooAbsArg*)_histObsIter->Next())) {
+      parg = (RooAbsArg*)_pdfObsIter->Next() ;
+      if (harg != parg) {
+	parg->syncCache() ;
+	harg->copyCache(parg,kTRUE) ;
+	if (!harg->inRange(0)) {
+	  return 0 ;
+	}
+      }
+    }
+  }
+
+  Double_t ret =  _dataHist->sum(intSet,_histObsList,kTRUE) ;
   return ret ;
 }
 
@@ -277,8 +382,24 @@ list<Double_t>* RooHistFunc::plotSamplingHint(RooAbsRealLValue& obs, Double_t xl
     return 0 ;
   }
 
+
+  // Find histogram observable corresponding to pdf observable
+  RooAbsArg* hobs(0) ;
+  _histObsIter->Reset() ;
+  _pdfObsIter->Reset() ;
+  RooAbsArg* harg, *parg ;
+  while((harg=(RooAbsArg*)_histObsIter->Next())) {
+    parg = (RooAbsArg*)_pdfObsIter->Next() ;
+    if (string(parg->GetName())==obs.GetName()) {
+      hobs=harg ; 
+    }
+  }
+  if (!hobs) {
+    return 0 ;
+  }
+
   // Check that observable is in dataset, if not no hint is generated
-  RooAbsLValue* lvarg = dynamic_cast<RooAbsLValue*>(_dataHist->get()->find(obs.GetName())) ;
+  RooAbsLValue* lvarg = dynamic_cast<RooAbsLValue*>(_dataHist->get()->find(hobs->GetName())) ;
   if (!lvarg) {
     return 0 ;
   }
@@ -320,9 +441,61 @@ std::list<Double_t>* RooHistFunc::binBoundaries(RooAbsRealLValue& obs, Double_t
     return 0 ;
   }
 
+  // Find histogram observable corresponding to pdf observable
+  RooAbsArg* hobs(0) ;
+  _histObsIter->Reset() ;
+  _pdfObsIter->Reset() ;
+  RooAbsArg* harg, *parg ;
+  while((harg=(RooAbsArg*)_histObsIter->Next())) {
+    parg = (RooAbsArg*)_pdfObsIter->Next() ;
+    if (string(parg->GetName())==obs.GetName()) {
+      hobs=harg ; 
+    }
+  }
+
+  // cout << "RooHistFunc::bb(" << GetName() << ") histObs = " << _histObsList << endl ;
+  // cout << "RooHistFunc::bb(" << GetName() << ") pdfObs = " << _depList << endl ;
+
+  RooAbsRealLValue* transform(0) ;
+  if (!hobs) {
+
+    // Considering alternate: input observable is histogram observable and pdf observable is transformation in terms of it
+    RooAbsArg* pobs(0) ;
+    _histObsIter->Reset() ;
+    _pdfObsIter->Reset() ;
+    while((harg=(RooAbsArg*)_histObsIter->Next())) {
+      parg = (RooAbsArg*)_pdfObsIter->Next() ;
+      if (string(harg->GetName())==obs.GetName()) {
+	pobs=parg ; 
+	hobs=harg ;
+      }
+    }
+
+    // Not found, or check that matching pdf observable is an l-value dependent on histogram observable fails
+    if (!hobs || !(pobs->dependsOn(obs) && dynamic_cast<RooAbsRealLValue*>(pobs))) {
+      cout << "RooHistFunc::binBoundaries(" << GetName() << ") obs = " << obs.GetName() << " hobs is not found, returning null" << endl ;
+      return 0 ;
+    }
+
+    // Now we are in business - we are in a situation where the pdf observable LV(x), mapping to a histogram observable x
+    // We can return bin boundaries by mapping the histogram boundaties through the inverse of the LV(x) transformation
+    transform = dynamic_cast<RooAbsRealLValue*>(pobs) ;
+  }
+
+
+  // cout << "hobs = " << hobs->GetName() << endl ;
+  // cout << "transform = " << (transform?transform->GetName():"<none>") << endl ;
+
   // Check that observable is in dataset, if not no hint is generated
-  RooAbsLValue* lvarg = dynamic_cast<RooAbsLValue*>(_dataHist->get()->find(obs.GetName())) ;
+  RooAbsArg* xtmp = _dataHist->get()->find(hobs->GetName()) ;
+  if (!xtmp) {
+    cout << "RooHistFunc::binBoundaries(" << GetName() << ") hobs = " << hobs->GetName() << " is not found in dataset?" << endl ;
+    _dataHist->get()->Print("v") ;
+    return 0 ;
+  }
+  RooAbsLValue* lvarg = dynamic_cast<RooAbsLValue*>(_dataHist->get()->find(hobs->GetName())) ;
   if (!lvarg) {
+    cout << "RooHistFunc::binBoundaries(" << GetName() << ") hobs = " << hobs->GetName() << " but is not an LV, returning null" << endl ;
     return 0 ;
   }
 
@@ -336,7 +509,15 @@ std::list<Double_t>* RooHistFunc::binBoundaries(RooAbsRealLValue& obs, Double_t
   // right of the bin boundaries
   for (Int_t i=0 ; i<binning->numBoundaries() ; i++) {
     if (boundaries[i]>=xlo && boundaries[i]<=xhi) {
-      hint->push_back(boundaries[i]) ;
+      
+      Double_t boundary = boundaries[i] ;
+      if (transform) {
+	transform->setVal(boundary) ;
+	//cout << "transform bound " << boundary << " using " << transform->GetName() << " result " << obs.getVal() << endl ;
+	hint->push_back(obs.getVal()) ;
+      } else {	
+	hint->push_back(boundary) ;
+      }
     }
   }
 
@@ -344,6 +525,7 @@ std::list<Double_t>* RooHistFunc::binBoundaries(RooAbsRealLValue& obs, Double_t
 }
 
 
+
 //_____________________________________________________________________________
 Bool_t RooHistFunc::importWorkspaceHook(RooWorkspace& ws) 
 {  
@@ -416,6 +598,7 @@ Bool_t RooHistFunc::areIdentical(const RooDataHist& dh1, const RooDataHist& dh2)
     dh2.get(i) ;
     if (fabs(dh1.weight()-dh2.weight())>1e-8) return kFALSE ;
   }
+  if (!(RooNameSet(*dh1.get())==RooNameSet(*dh2.get()))) return kFALSE ;
   return kTRUE ;
 }
 
@@ -436,3 +619,16 @@ void RooHistFunc::Streamer(TBuffer &R__b)
    }
 }
 
+
+//______________________________________________________________________________
+void RooHistFunc::ioStreamerPass2() 
+{
+  // Schema evolution: if histObsList wasn't filled from persistence (v1)
+  // then fill it here. Can't be done in regular schema evolution in LinkDef
+  // as _depList content is not guaranteed to be initialized there
+
+  if (_histObsList.getSize()==0) {
+    _histObsList.addClone(_depList) ;
+  }
+}
+
