@@ -37,6 +37,7 @@
 #include "RooCategory.h"
 #include "RooNameSet.h"
 #include "RooHistError.h"
+#include "RooTrace.h"
 
 #include <iomanip>
 #include <algorithm>
@@ -72,8 +73,10 @@ RooVectorDataStore::RooVectorDataStore() :
   _curWgtErrHi(0),
   _curWgtErr(0),
   _cache(0),
-  _cacheOwner(0)
+  _cacheOwner(0),
+  _forcedUpdate(kFALSE)
 {
+  TRACE_CREATE
 }
 
 
@@ -101,7 +104,8 @@ RooVectorDataStore::RooVectorDataStore(const char* name, const char* title, cons
   _curWgtErrHi(0),
   _curWgtErr(0),
   _cache(0),
-  _cacheOwner(0)
+  _cacheOwner(0),
+  _forcedUpdate(kFALSE)
 {
   TIterator* iter = _varsww.createIterator() ;
   RooAbsArg* arg ;
@@ -111,6 +115,7 @@ RooVectorDataStore::RooVectorDataStore(const char* name, const char* title, cons
   delete iter ;
   
   setAllBuffersNative() ;
+  TRACE_CREATE
 }
 
 
@@ -218,6 +223,7 @@ RooVectorDataStore::RooVectorDataStore(const RooVectorDataStore& other, const ch
   _firstReal = _realStoreList.size()>0 ? &_realStoreList.front() : 0 ;
   _firstRealF = _realfStoreList.size()>0 ? &_realfStoreList.front() : 0 ;
   _firstCat = _catStoreList.size()>0 ? &_catStoreList.front() : 0 ;
+  TRACE_CREATE
 }
 
 
@@ -262,6 +268,7 @@ RooVectorDataStore::RooVectorDataStore(const RooTreeDataStore& other, const RooA
     _varsww = other._varsww ;
     fill() ;
   }
+  TRACE_CREATE
   
 }
 
@@ -329,6 +336,7 @@ RooVectorDataStore::RooVectorDataStore(const RooVectorDataStore& other, const Ro
   _firstReal = _realStoreList.size()>0 ? &_realStoreList.front() : 0 ;
   _firstRealF = _realfStoreList.size()>0 ? &_realfStoreList.front() : 0 ;
   _firstCat = _catStoreList.size()>0 ? &_catStoreList.front() : 0 ;
+  TRACE_CREATE
 
 }
 
@@ -387,6 +395,7 @@ RooVectorDataStore::RooVectorDataStore(const char *name, const char *title, RooA
   loadValues(&tds,cloneVar,cutRange,nStart,nStop);
 
   delete cloneVar ;
+  TRACE_CREATE
 }
 
 
@@ -414,6 +423,7 @@ RooVectorDataStore::~RooVectorDataStore()
   }
 
   delete _cache ;
+  TRACE_DESTROY
 }
 
 
@@ -1255,6 +1265,10 @@ void RooVectorDataStore::cacheArgs(const RooAbsArg* owner, RooArgSet& newVarSet,
 }
 
 
+void RooVectorDataStore::forceCacheUpdate()
+{
+  if (_cache) _forcedUpdate = kTRUE ; 
+}
 
 
 
@@ -1269,7 +1283,7 @@ void RooVectorDataStore::recalculateCache( const RooArgSet *projectedArgs, Int_t
 
   // Check which items need recalculation
   for (Int_t i=0 ; i<_cache->_nReal ; i++) {
-    if ((*(_cache->_firstReal+i))->needRecalc()) {
+    if ((*(_cache->_firstReal+i))->needRecalc() || _forcedUpdate) {
       tv[ntv] = (*(_cache->_firstReal+i)) ;
       tv[ntv]->_nativeReal->setOperMode(RooAbsArg::ADirty) ;
       tv[ntv]->_nativeReal->_operMode=RooAbsArg::Auto ;
@@ -1277,6 +1291,7 @@ void RooVectorDataStore::recalculateCache( const RooArgSet *projectedArgs, Int_t
       ntv++ ;
     }    
   }
+  _forcedUpdate = kFALSE ;
 
   // If no recalculations are neede stop here
   if (ntv==0) {
