@@ -31,7 +31,7 @@
 //                                                                          //
 // Interval definition, continuous and discrete                             //
 //                                                                          //
-// Interval(min,max)  : a continuous interval [min,max]                      //
+// Interval(min,max)  : a continous interval [min,max]                      //
 // Interval(min,max,n): a "discrete interval" [min,max], i.e the n numbers: //
 //          min, min+step, min+2*step,...., min+(n-1)*step, min+n*step=max  //
 //   e.g.: Interval(1,5,5)=1,2,3,4,5                                        //
@@ -69,27 +69,31 @@ namespace TMVA {
       virtual ~Interval();
 
       // accessors
-      Double_t GetMin()   const { return fMin; }
-      Double_t GetMax()   const { return fMax; }
-      Double_t GetWidth() const { return fMax - fMin; }
-      Int_t    GetNbins() const { return fNbins; }
-      Double_t GetMean()  const { return (fMax + fMin)/2; }
-      Double_t GetRndm( TRandom3& )  const;
-      Double_t GetElement( Int_t position ) const;      
-      Double_t GetStepSize() const;
+      // accessors
+      virtual Double_t GetMin()   const { return fMin; }
+      virtual Double_t GetMax()   const { return fMax; }
+      virtual Double_t GetWidth() const;
+      virtual Int_t    GetNbins() const { return fNbins; }
+      virtual Double_t GetMean()  const;
+      virtual Double_t GetRndm( TRandom3& )  const;
+      virtual Double_t GetElement( Int_t position ) const;      
+      virtual Double_t GetStepSize(Int_t iBin=0) const;
 
       void SetMax( Double_t m ) { fMax = m; }
       void SetMin( Double_t m ) { fMin = m; }
 
-   private:
+      virtual void Print( std::ostream& os ) const;
+
+   protected:
 
       Double_t fMin, fMax;    // the constraints of the Interval
       Int_t    fNbins;        // when >0 : number of bins (discrete interval); when ==0 continuous interval
 
+   private:
       static MsgLogger* fgLogger;   // message logger
       MsgLogger& Log() const { return *fgLogger; }          
 
-      ClassDef(Interval,0)    // Interval definition, continuous and discrete
+      ClassDef(Interval,0)    // Interval definition, continous and discrete
    };
 
 } // namespace TMVA
