@@ -1,4 +1,4 @@
-// @(#)root/treeviewer:$Id: TParallelCoordVar.cxx 43188 2012-03-01 09:31:20Z couet $
+// @(#)root/treeviewer:$Id$
 // Author: Bastien Dalla Piazza  02/08/2007
 
 /*************************************************************************
@@ -385,8 +385,8 @@ void TParallelCoordVar::GetMinMaxMean()
 {
    //Get mean, min and max of thos variable
    Double_t min,max,ave = 0;
-   min = FLT_MAX;
-   max = -FLT_MAX;
+   min = DBL_MAX;
+   max = -DBL_MAX;
    Long64_t first,nentries;
    first = fParallel->GetCurrentFirst();
    nentries = fParallel->GetCurrentN();
